Handbook - Nervous System General Description
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

NERVOUS SYSTEM GENERAL DESCRIPTION Click pictures for new window with figure and legend, click again for high resolution image
1 Overview The adult C. elegans hermaphrodite has 302 neurons that belong to two distinct and independent nervous systems: a large somatic nervous system (282 neurons) and a small pharyngeal nervous system (20 neurons). These systems communicate through a single pair of RIP interneurons (NeuroFIG 1) (Ward et al., 1975; Sulston and Horvitz, 1977; Sulston et al., 1983; White et al., 1986). (For a discussion of the pharyngeal nervous system, see Alimentary System - Pharynx ) The two nervous systems differ in their topologies. In the somatic nervous system, the neurons and their processes are generally positioned between the hypodermis and the body wall muscle and share a basal lamina with the hypodermis that isolates them from the muscles (NeuroFIG 2). In contrast, the pharyngeal neurons lie directly among the pharyngeal muscles and are not separated from their muscle targets by a basal lamina. The neurons in the hermaphrodite have been assigned to 118 distinct classes according to their topology and synaptic connection patterns (White et al., 1986). Cell bodies of most neurons are clustered in ganglia in the head or tail (NeuroFIG 1). C. elegans has 56 neuronal support cells (including the GLR cells; see Muscle System - GLR Cells), which are associated only with the somatic nervous system. The neurons communicate through approximately 6400 chemical synapses, 900 gap junctions, and 1500 neuromuscular junctions (NMJs). Among individual animals, the location of chemical synapses is about 75% reproducible (Durbin, 1987). Every C. elegans neuron name consists of either two or three uppercase letters indicating class and in some cases a number indicating the neuron number within one class. If the neurons are radially symmetrical, each cell has a three-letter name followed by L (left), R (right), D (dorsal), or V (ventral). A complete list of C. elegans neurons, their lineage, and descriptions can be found in the Individual Neuron section of the WormAtlas. NeuroFIG 1: The C. elegans nervous system. A. Epifluorescent image of a transgenic animal expressing a panneural reporter, left lateral view. The largest collection of neurons is around the nerve ring (NR) within several head ganglia, including the retrovesicular ganglion (RVG) and ventral ganglion (VG; also, inset). The second largest collection of cell bodies is in the tail ganglia (the left lumbar ganglion and preanal ganglion are shown). A few single neurons, including ALM, CAN, or small groups of neurons (lateral ganglia), are also found along the lateral body wall. Longitudinal nerve tracts travel along the body at ventral, subventral, lateral, subdorsal, and dorsal positions and connect cell bodies to major neuropils. Anterior to the ring, several sensillar nerves reach the tip of the head. VNC (ventral nerve cord) motor neurons are scattered along the VNC and send processes to the DC via commissures (arrowheads). The pharyngeal nervous system is an autonomous network of 20 pharyngeal neurons (NSML, which is situated within the anterior bulb, inset). Note that this reporter is also expressed in head muscle cells (arrows, inset). Magnification, 400x. Strain marker: unc119::GFP. (Strain source: CGC.) B–D. Differential interference contrast (DIC) images of the head of a young adult animal at three planes, viewed from the left side. B. On the lateral side are left-side lateral ganglion nuclei posterior to the NR. C. At a more medial level, more NR fibers are seen extending from the VNC and growing around the isthmus (black circle). Neurons of the dorsal ganglion (neuron nuclei) become visible at this level. D. At a slightly more medial level, multiple labial neuron and support cell nuclei become visible anterior to the NR around the anterior bulb, whereas more lateral ganglion nuclei are visible posterior to the NR. Magnification, 600x. NeuroFIG 2A-C: Placement and topology of somatic neurons. A&B. Schematic cross sections through the anterior midbody. Neurons are bounded by the basement membrane of the hypodermis. The lateral touch receptor neurons (ALM in the anterior body, PLM in the posterior body) run on the peripheral side of the hypodermis, whereas VNC, DC, and canal-associated nerves run on the inside between the hypodermis and pseudocoelom. The sublateral (subdorsal and subventral) cords lie just inside a thin layer of hypodermis near body wall muscles. (Orange) Basal lamina; (yellow) pseudocoelom; (green) body wall muscle. C. Sensory nerves in the head. Cross section near the lips. Most of the neurons are components of the various head sensilla with associated sheath and socket cells. Exceptions are URX, URY, BAG, and FLP neuron processes that run in the sensillar nerves but do not end in the sensillar endings. Outer labial quadrant (OLQ) nerves and cephalic (CEP) nerves have fourfold symmetry, whereas inner labial (IL1 and IL2) nerves have sixfold symmetry. Amphid nerves and outer labial lateral (OLL) nerves have twofold symmetry and run on the sides of the head. (Bright aqua) Amphid sheath; (dark aqua) sheath of the other sensilla; (purple) pharyngeal epithelium; (green) head muscle cell quadrants; (beige) hypodermis; (PH) buccal cavity pharyngeal lumen. Cross section roughly corresponds to a transmission electron microscopy (TEM) section between MRC N2 (“nose”) 3731-4 and 3731-19 (not shown). NeuroFIG 2D&E: Placement and topology of somatic neurons. D. Neurons (purple, red) are positioned between the hypodermis (beige) and the hypodermal basal lamina (orange line). Arms from the muscles (green) reach the nerves to receive input at neuromuscular junctions that traverse the basal laminae. Synapses between neurons and muscles and between neurons are made en passant at process swellings (arrowheads). E. Epifluorescent image of a transgenic animal expressing cyan fluorescent protein (CFP) in D-type motor neurons. GABAergic synaptic varicosities in the motor neurons, specifying the GABA release sites at NMJs, are seen in a punctate manner along the nerve. Some SNB-1-CFP accumulates in motor neuron soma (arrows). Strain marker: Punc-47::snb1::CFP (synaptobrevin under the control of unc-4 promoter and tagged with CFP). Bar, 20 μm. (Image source: C. Gally and J.L. Bessereau.) Males have a larger nervous system with 473 cells (with an additional 79 neurons and 36 support cells). Most of these extra, male-specific cells are involved in male mating behavior and are located in the posterior body (Sulston et al., 1980; Lipton and Emmons, 2003; Emmons, 2005). The four CEM (cephalic neuron in male) neurons are an exception; they are located in the head as part of the male cephalic sensilla. The hermaphrodite has only two classes of hermaphrodite-specific neurons: HSN, which are generated in males but go through programmed cell death during early development, and VC neurons, which are derived from the P lineages that give rise to cells of the hook sensillum in males. All of the neurons in both sexes have been individually identified and their lineages described. The connectivity among the hermaphrodite neurons has been established from electron micrographs of serial thin sections, whereas the connectivity of the male nervous system has been the focus of more recent studies (Ward et al., 1975; Ware et al., 1975; White et al., 1986; Durbin, 1987; Hall and Russell, 1991; Chen et al., 2006; see also Male Anatomy. Despite its compact nervous system, C. elegans is capable of several complex behaviors, in addition to the basics such as locomotion, foraging, feeding, and defecation (de Bono and Maricq, 2005). The animal can discriminate and move toward or away from chemicals, odorants, temperatures, and food sources. It can also detect the presence, density, and sex of nearby nematodes by short-range diffusible signals, by a pheromone, and by changes in oxygen levels (Riddle and Golden, 1982; Cheung et al., 2004; Gray et al., 2004; Jeong et al., 2005; Barr and Garcia, 2006). The animal displays social feeding behavior (de Bono, 2003). Each sex also displays sex-specific behaviors such as egg-laying in hermaphrodites and mating behavior in males (Schafer, 2005). Most of these behaviors are plastic and therefore subject to change through learning and memory (Giles et al., 2006). Additionally, food is a significant modulator of many C. elegans behaviors, including egg-laying, feeding, locomotion, and olfactory behavior, often through serotonin-dependent pathways (Zhang et al., 2005). The neuron circuits that are dedicated to each of these behaviors may communicate via interneurons to produce hierarchies in their execution. For example, in stressful environments where food is scarce, egg-laying behavior is suppressed, whereas after an encounter with food, locomotion behavior becomes suppressed in a starved animal, allowing the animal to feed properly.
2 Neurons Almost all C. elegans neurons have simple monopolar or bipolar morphologies with mostly unbranched processes that follow nearly identical trajectories in each animal (NeuroFIG 3). A few motor neurons, including VC4 and HSN neurons, make several simple branches as they reach their muscle targets. PVD and FLP neurons are unique in C. elegans because they branch extensively near each body muscle quadrant after early larval stages. Many neurons in the adult male tail are also more highly branched within the preanal ganglion, where some neurons can have four to eight separate branches within the neuropil (S.W. Emmons, J.E. Sulston, D.G. Albertson, M. Xu, and D.H. Hall, unpubl.). Some neuron processes may have pure sensory functions (a dendrite) or pure synaptic output functions (an axon), but many have mixed functions capable of both receiving inputs and sending outputs (a neurite or process). NeuroFIG 3: Branching patterns of C. elegans neurons. A&B. Most C. elegans neurons have simple monopolar or bipolar structures. A. Epifluorescent micrograph of an adult animal expressing the str-2::GFP reporter in the AWCL neuron, left lateral view. The dendrite of the sensory neuron (arrow) extends to the tip of the nose, whereas the axon (arrowhead) passes through the amphid commissure to enter the nerve ring, where it makes synaptic contacts. This is one of the few neurons in the worm that has a distinct dendrite and an axon. Magnification, 600x. (Strain source: C. Bargmann.) B. Epifluorescent image, ventral view. An adult animal expressing the zig-2::GFP reporter in PVT, which is a single, monopolar neuron located in the preanal ganglion. Its process (arrow) travels anteriorly to the nerve ring within the right fascicle of the VNC. Magnification, 600x. (Strain source: O. Aurelio and O. Hobert.) C&D. A few neurons have more complex branching patterns. C. Ventral view. HSN axon outgrowth begins during L2 and L3, and its main axon reaches the nerve ring by the late-L4 stage (see Reproductive System - Egg-laying apparatus). Vulval precursor cells guide the emerging HSN processes and induce them to form several short branches (arrowheads [left side is slightly out of focus]) at the vulva. Epifluorescent micrograph of an adult animal expressing the arrestin::GFP reporter in HSN neurons. Magnification, 600x. (Strain source: G. Garriga and C. Bargmann.) D. Lateral views. PVD neurons display the most complex arborization pattern in the worm. In larval stages (top), three major processes can be discerned—one anteriorly directed, one posteriorly directed, and one ventrally directed (arrowheads). These processes have short branches along their length. As the animal ages (bottom), this branching pattern is extensively elaborated and covers most of the body with secondary branches. Epifluorescent image of an animal stained with DEG-3 antibodies. (Image source: M. Treinin.) Neuronal somata are among the smallest in the nematode. In transmission election microscopy (TEM) sections, they are seen as having relatively lightly staining cytoplasm, with a compact nucleus, distinctive rough endoplasmic reticulum (RER), several mitochondria, small clusters of synaptic vesicles, and one or more Golgi bodies. Most of the neuronal nucleus is filled with light-staining “euchromatin,” with a modest amount of dark “heterochromatin,” and one or more small round nucleoli. Under differential interference contrast (DIC) microscopy, neuronal nuclei can easily be distinguished as small, stippled ovals (NeuroFIG 1). The processes of individual neurons are generally very thin (100–200 nm in diameter), but show local swellings with clusters of vesicles at synaptic regions along the length of the process (White et al., 1986). Within each neurite or major side branch, a small bundle of microtubules (MTs) runs continuously along its length. In addition, each neurite contains a small tube of smooth endoplasmic reticulum (ER) and occasional mitochondria. A few small clusters of free ribosomes sometimes lie within the neurite not far from synapses, either on the presynaptic or post-synaptic side (Rolls et al., 2002). The exact position of synaptic swellings or short side branches is not identical among animals; however, the polarity, handedness, and position of a cell’s main processes are very predictable. 2.1 Nervous System Development 2.1.1 Cell Birth, Programmed Cell Death and Cell Migration C. elegans neurons are generated at three main developmental periods. The first is during the proliferation phase of embryogenesis, the second at the late-L1 stage, and the third at the L2 stage (Sulston and Horvitz, 1977; Sulston et al., 1983). At the time of hatching, the hermaphrodite worm has 222 neurons (202 somatic, 20 pharyngeal) and most of these derive from the AB lineage (the male worm has 224 neurons at this stage). All of the glial cells arise from the AB lineage. MS (six neurons) and C (two neurons) lineages contribute only a few neurons to the nervous system. During late L1, five classes of ventral nerve cord (VNC) motor neurons are generated from P and W lineages (see Postembryonic Neurons Table). Also at this time, additional neurons are generated from Q, G1, H2, T, and K lineages. In the L2 stage, the G2 blast cell divides to give rise to the excretory socket cell and RMF neuron pair, and V5paa generates the cells of the posterior deirids on both sides (see Epithelial system - Hypodermis). In males, the additional neurons that function in male mating are born during the L3 stage (Sulston et al., 1980). As a general rule in C. elegans neurogenesis, most bilaterally symmetric pairs of neurons arise from bilaterally symmetric cell lineages, but there are exceptions to this rule. C. elegans uses programmed cell death in two contexts during neurogenesis: to generate sexual dimorphism in certain parts of the nervous system (death of CEM cells in the hermaphrodite and HSN cells in the male) and to eliminate extra motor neuron production in the VNC. The ap daughters of P3a–P8a become VNC motor neurons, whereas the corresponding cells in the other P lineages die (see Epithelial system - Hypodermis). Similarly, P11aaap and P12aaap are eliminated instead of becoming additional VB cells (Sulston, 1976). Developmentally, neuronal cell movements can be divided into early mass migrations and later individual cell migrations. During embryogenesis, mass neuroblast movements occur to close the ventral cleft (at ~230–290 min after first cell cleavage, dorsal and lateral neurons sink towards inside and adjacent hypodermal cells cover the ventral side). They also occur later at comma stage when anterior neuron groups move toward the tip of the head to form rudiments of the head sensilla (see Epithelial system - Hypodermis). During this time, a sensory depression forms at the tip of the head to provide more surface area for the newly forming sensilla, and later everts (Sulston et al., 1983). Cell bodies of the head sensilla neurons later migrate posteriorly, leaving their dendritic processes stretching behind as attached to the lips. Two extracellular matrix proteins , DYF-7 and DEX-1, are required to anchor these nascent dendritic processes to the lips, since in dyf-7 or dex-1 mutants dendrites remain short and stubby and are dragged along by the neuron cell bodies as they pull away (Heiman & Shaham, 2009). Additionally, the anchoring of dendrites of amphid neurons of each side is highly coordinated, since failure of one dendrite to anchor leads to the failure of attachment of the remaining dendrites of the same side. Subsequent to these events, during elongation, the head neurons are pushed aside as the pharynx grows forward through the mass of neurons surrounding the developing nerve ring (NR). By late embryogenesis, the neurons around the NR settle into their recognizable positions. In later stages, despite the mechanical force generated by body movements, the organization of cells in head ganglia is mostly maintained through homophilic and heterophilic interactions of cell adhesion molecules expressed on the surfaces of the neurons (Sasakura et al., 2005). There are some exceptions to this however; in live animals, cells can sometimes be seen to flip from one side of the anterior bulb to the other as the pharynx moves (Z. Altun, unpublished observations; White et al., 1986). Although relative positions of cell bodies within ganglia are fairly well conserved between animals of the same developmental stage and genotype, there is still a certain amount of natural variation. These fall into four groups (Z. Altun, unpublished observations; Bargmann and Avery 1996): 1- posterior lateral ganglia neurons (e.g. AIN, RIC, AIZ, ADEso, AVD) 2- postembryonic neurons in the tail (e.g. PHC, PLN, PVN, PVW) 3- postembryonic neurons in the ventral cord (ASn, VAn, VBn, VCn, VDn) 4- the anterior socket and sheath cells in the head, such as ILsh, ILso, OLQso The most extreme cases of variability of cell position in the head are seen around the anterior bulb of the pharynx which fits fairly tightly in the body cavity and excludes these cell bodies from its region of maximum diameter. This leads to variability in the position of cell bodies with respect to the bulb. For example, in the N2U animal, OLQsoDL lies anterior to the bulb, whereas its symmetrical partner, OLQsoDR, lies posterior to the bulb (White et al., 1986). Most neurons are born close to their ultimate positions and need migrate only short distances. However, there are a few neurons that must migrate long distances after they are born (NeuroFIG 4A,B) (Hedgecock et al., 1987; Montell, 1999). This group includes canal-associated neurons (CAN), which move from the anterior end to a location midway along the body; HSN neurons, which move from the posterior end to close to the vulva; and anterior lateral microtubule (ALM) neurons, which move posteriorly from the anterior edge of the intestine to midway within the anterior body. QR and QL neuroblasts also migrate extensively (NeuroFIG 4). QR and QL are born about 1 hour before hatching at symmetric locations on the right and left sides of the posterior body, respectively, but after cell migrations their terminally differentiated progeny reside in nonsymmetric positions. Soon after hatching, QR migrates anteriorly, whereas QL migrates posteriorly. Their descendents continue migrating asymmetrically to anterior positions on the right side and posterior positions on the left (Salser and Kenyon, 1992). Each Q lineage produces a mechanosensory neuron (AVM/PVM), a sensory neuron (AQR/PQR), an interneuron (SDQR/L), and two programmed cell deaths. NeuroFIG 4A-D: Asymmetries in the C. elegans nervous system. A&B. Some neurons migrate long distances during development to reach asymmetrical target positions along the body. A. Larval migration of Q blast cells and their progeny. The progeny that die are indicated by an “x” within a circle. (Arrows) Routes of migration of Q blast cells and their progeny. B. CAN, HSN, and ALM neurons also migrate, but their terminally differentiated, left and right progeny are symmetrically located along the body. (Go) Gonad primordium. C. Most neuron processes that exit the NR from the left side decussate to the right fascicle of the VNC, generating asymmetric thickness between the right and left sides of the VNC. Processes that exit from the right side of the NR do not decussate. (e) Excretory pore. D. Left lateral-oblique view. After exiting the NR from the left side, most fibers cross to the right side (arrow), posterior to the excretory pore (e). Epifluorescent image of a transgenic animal expressing the pan-neural unc-119::GFP transgene. Magnification, 1000x. (Strain source: CGC.) NeuroFIG 4E-G: Asymmetries in the C. elegans nervous system. E. Ventral view seen from the dorsal. The AVKR process does not cross to the right side after exiting the NR on the left and remains on the left side of the VNC (arrowhead). (Blue dotted line) Ventral midline. Epifluorescent image of a transgenic animal expressing the flp-1::GFP transgene in AVK neurons. Magnification, 600x. (Strain source: B. Wightman and C. Li.) F. Ventral view seen from the dorsal. PVQ neurons grow processes in the left and right tracts of the VNC (arrowheads). After entering the preanal region from the left lumbar commissure, the PVQL process briefly runs along the process of PVQR before extending into the left tract of the VNC. (Arrow) Vulva; (blue dotted line) midline. Epifluorescent image of a transgenic animal expressing the sra-6::GFP transgene in PVQ neurons. Magnification, 600x. (Strain source: T. Sarafi-Reinach and P. Sengupta.) G. Schematic view of neurons that pioneer the left and right fascicles of the VNC. The body posterior to the NR is shown as if opened along the dorsal midline in cylindrical projection while the nerve ring is flattened toward the anterior. (Circle) Excretory pore at the anterior of the ventral midline; (light red ovals) ganglia. For clarity, neurons are given individual colors that are different from the color code used throughout this Atlas. (Based on White et al., 1986; Wadsworth et al., 1996.) Some neurons display delayed maturation during development. The Y cell functions as a rectal epithelial cell until early larval stages, but later becomes terminally differentiated as PDA in the hermaphrodite. The embryonically born HSN neurons develop synapses onto newly born sex muscles only in the L3 and L4 stages (White et al., 1986). Similarly, VC neurons branch onto sex muscles in the L4 stage. DD motor neurons acquire their final synaptic connection pattern at the late-L1 stage, after the birth of VD neurons, and AVM neurons become connected to the anterior touch circuit at the late-L4 stage (Chalfie and White, 1988; Walthall et al., 1993). 2.1.2 Process Outgrowth, Establishment of Process Tracts and Guidance at the Midline The nervous system of C. elegans displays handedness at many places. First, although the majority of neurons are in pairs and localize on the right and left sides of the animal in a bilaterally symmetric manner, there are many unilaterally placed single neurons. Additionally, members of some neuron pairs, such as SDQL/SDQR and AQR/PQR, are positioned far away from one another in a nonsymmetrical manner (NeuroFIG 4). Second, the two major cords of the animal, the VNC and dorsal cord (DC), are asymmetrical in their composition or location (NeuroFIG 4 and NeuroFIG 5). The DC is located at the left side of the dorsal hypodermal ridge, whereas the VNC has a thick fascicle on the right side of the ventral hypodermal ridge and a thin fascicle on the left. Third, the neurons in the body choose the side of the body on which to send their processes; although the pair of HSN neurons extends its neurites ipsilaterally along the two VNC tracts, many neuron pairs, such as PVD and PDE, have both of their neurites in the right tract, which requires the left-sided process to cross the midline. Similarly, the VNC motor neurons, which are localized at the midline, make “choices” regarding the side on which to grow their circumferential processes, whereas all of them extend their ventral processes along the right VNC tract. The right fascicle of the VNC is further populated by some NR processes that exit the NR on the left side, but then decussate to the right to continue extending within the VNC (NeuroFIG 5, top panel right side and panel C) (White et al., 1986). NeuroFIG 5: Composition and placement of dorsal cord (DC) and ventral nerve cord (VNC). Top panel, left side shows an illustration indicating the approximate section levels for the TEMs shown below.Top panel, right side shows an epifluorescent image of the neuron process crossover on the ventral side. A–D. Sections through the VNC. In all panels, arrows indicate AVM process running at the extreme ventral region of the VNC. E. Section through the DC. All are transverse sections, and the nerve bundles and cell bodies in all sections are indicated by dotted red lines. Bars, 1 μm. A. Immediately posterior to the nerve ring, at the anterior ventral ganglion, all the processes coalesce into a thick, single bundle. Anterior to this region, processes enter the ring from either the right or the left side. Cephalic sheath cells wrap around the cord on the ventral and lateral sides. (Asterisks) Excretory gland processes that terminate in the ventral regions of the NR. (Image source: [MRC] N2U[VC]-208-20a.) B. Posterior to the ventral ganglion, the excretory pore splits the VNC into two bundles of approximately equal thickness. (Image source: [MRC] N2U[VC]-222-17a.) C. Posterior to the pore, the nerve fibers gradually cross (decussate) from the left side to the right of the ventral hypodermal ridge (Hyp). Arrowheads indicate two such neurites in the process of crossing over the midline. (Image source: [MRC] N2U[VC]-228-12a.) D. Slightly more posteriorly, the VNC is composed of a thin left bundle and a thick right one separated by the ventral hypodermal ridge. Cell bodies of RVG neurons are located dorsal to the right bundle. (hmc) Head mesodermal cell; (Ps) pseudocoleomic cavity. (Image source: [MRC] N2U[VC]-241-7a.) E. The DC is positioned on the left side of the dorsal hypodermal ridge. Commissures that reach the dorsal side from the right must cross the midline over the hypodermal ridge to reach the DC. (Amsh) Amphid sheath; (Hyp) hypodermal ridge. (Image source: [MRC] N2U[DC]-213-18a.) Asymmetry within the C. elegans VNC is established embryonically by pioneer neurons and midline cues provided by neuronal and nonneuronal (e.g., hypodermal and glial) tissues (NeuroFIG 4). AVG and PVT neurons mark the anterior and posterior boundaries of the VNC. AVG is the anterior guidepost neuron that pioneers the right tract of the VNC, whereas PVPR pioneers the left tract from the posterior, followed by the PVQL process (Durbin, 1987; Wadsworth and Hedgecock, 1996; Wadsworth et al., 1996). PVQ axons pioneer the lumber commissures and continue to travel alongside the PVP processes in the VNC. Although the PVPR axon is absolutely required for proper outgrowth of left-tract neurites, the AVG axon is essential for the correct outgrowth of only a subset of processes into the right tract (Hutter, 2003; Hutter et al., 2005). PVT, a single neuron in the preanal ganglion, serves as a guidepost neuron to growing axons from the lumbar ganglia in the posterior of the VNC. When PVT is ablated embryonically, these axons follow multiple routes to enter the VNC instead of making tight bundles in the two lumbar commissures (Wadsworth et al., 1996; Antebi et al., 1997; Ren et al., 1999). PVT is also required for maintenance of neurite architecture in the VNC post-embryonically, because in the absence of PVT, embryonically generated neurites are unable to maintain their positioning along the cord at the L1 stage and erroneously cross over the midline into the opposite fascicle (Aurelio et al., 2002; Hobert and Bülow, 2003). BDU processes are required for correct positioning of AVM branches in the NR (Chalfie and White, 1988). Notably, RIF neurons, which are the first processes to cross the ventral midline between the NR and the beginning of the VNC, are not essential for providing the pathway for guiding processes into the right VNC fascicle at the anterior decussation (Durbin, 1987; Hutter, 2003). The two neuron pairs, which decussate shortly after RIF, SABVs, and RIGs, are also not essential for this function. Of the 302 neurons in the adult hermaphrodite,180 project axons/processes into the NR. In the developing embryo, these axons that form the nerve ring must navigate to the NR within commissural and longitudinal nerve bundles, recognize the region of the NR, make L/R side choices to enter the NR, make specific contacts with each other to form synapses and maintain these contacts during later growth. Additionally, head and neck muscle development has to be coordinated with the longitudinal and commissural tract and nerve ring development. Currently, little is known about the procession and control of the NR development. Based on studies of embryos at 350 min and 430 min (after first cleavage,) it has been suggested that SIBD neurons act as pioneers to might provide a substrate for the formation of early amphid commissure, while RIH and RMEV might help navigate the first axons entering the NR from the ventral side (Norris, C., Hall, D. H., Hedgecock, E. unpublished observations) (NeuroFIG 15-2). In the early neurula, head muscle cells directly surround the pharynx where the NR will form and hence may restrict the access of lateral axons to reach the NR until the muscle cells move dorsally and ventrally to the periphery to their usual positions next to the hypodermis. As they migrate, they are suggested to leave railing processes behind attached to the NR, forming the arms of the head muscles (see Somatic Muscle). Outgrowth, branching, and shaping of neuronal processes, which are dependent on intrinsic cytoskeletal dynamics and extrinsic cues, are highly stereotyped in C. elegans. Mutant studies have uncovered several genes that seem to be involved in proper process outgrowth and suppression of excess axon branching (Altun-Gultekin et al., 2001; Knobel et al., 2001; Bülow et al., 2002). Neurons that extend commissures use the classical UNC-6/netrin and SLT-1/ slit pathways, which act redundantly, as well as additional pathways that act in parallel to these, for circumferential guidance along the dorsoventral axis (for review, see Chisholm and Jin, 2005). Intrinsically, cytoskeletal rearrangements are regulated by Rac GTPases and the actin-binding protein UNC-115 (Yang and Lundquist, 2005). Extracellularly, guidance cues are modified by heparan sulfate proteoglycans, which affect neurite branching and patterning in a cellular context-dependent manner (Bülow and Hobert, 2006.) Although the mechanisms for branch-point control are still unclear, branching generally occurs under four circumstances: (1) Processes may enter midway along an existing nerve and bifurcate and grow in both directions; (2) processes are confronted with two equivalent neighborhoods, such as the entrance to the NR, and they may split and grow into both; (3) within the NR, processes may also bifurcate to enter two different neighborhoods; and finally, (4) processes in longitudinal nerves may bifurcate and grow a branch circumferentially into another nerve (Hedgecock et al., 1987). 2.1.3 Developmental Plasticity The C. elegans nervous system exhibits various forms of plasticity as it matures. At the end of the L1 stage, post-embryonically born body wall muscles and five classes of newly born motor neurons are incorporated into the existing motor system and novel neuromuscular junctions are established, suggesting reciprocal responsiveness between the muscles and motor neurons. The end of the first larval stage also marks the rewiring of the synaptic contacts of DD motor neurons after the birth of VD motor neurons. This rewiring is intrinsically controlled and is not dependent on VD, VA, or VB neurons (White et al., 1978). Additionally, the neurons maintain similar densities of synapses during the fivefold increase in body length as the animal goes through four larval stages, suggesting that the nervous system maintains a certain level of plasticity throughout life and adjusts itself to the overall growth. 2.2 Neuron Categories C. elegans neurons fall into four functional categories defined by their circuitry: (1) motor neurons, which make synaptic contacts onto muscle cells; (2) sensory neurons, which have obvious sensory specializations (behavioral or mutant paradigms now demonstrate defined sensory functions for most of these cells, but some cells only have inferred or yet obscure sensory capabilities; NeuroTABLE 1); (3) interneurons, which receive incoming synapses from and send outgoing synapses onto other neurons; and (4) polymodal neurons, which perform more than one of these functional modalities. A pair of pharyngeal neurons, NSML/R, have prominent secretory terminals and are classified as neurosecretory neurons (they also have motor function; see Alimentary System - Pharynx). Besides these categories, there is a small subset of neurons whose functions are yet unknown. Some of these may be more important in process guidance or maintenance than in circuitry (Durbin, 1987; Chen et al., 2006; Hall et al., 2006). NeuroTABLE 1: Hermaphrodite sensory receptors. Male has many additional sensors (Sulston et al., 1980; Liu and Sternberg, 1995; Hall et al., 2006). Each entry includes cell name (cell number, position in the body). Some neurons are represented under several categories according to current information, but additional sensory modalities may yet be found for any of these sensors. Sensory neurons in C. elegans perform specific functions. Sixty of these contain modified, nonmotile cilia; 32 of these ciliated neurons are chemosensory and 26 are exposed to the environment through several sensilla (Bargmann and Mori, 1997; Mori, 1999; Melkman and Sengupta, 2004). Six unexposed, ciliated, sensillar neurons sense odorants and two others are involved in thermotaxis. Some of the remaining ciliated neurons as well as a subset of nonciliated neurons possess mechanosensory and proprioceptive functions. 1 ASH neurons mediate avoidance from noxious odors (octanol), hyperosmolarity, mechanical stimuli, heavy metals, bitter substances (quinine), and low pH (Kahn-Kirby and Bargmann, 2006). 2May be sensing food within pharyngeal lumen. 3Contain striated rootlet (only in males for PHC). 4Sense surface texture (e.g., roundness of bacteria, sephadex beads); food-mediated slowing response (Sawin et al., 2000). 5Dauer formation (entry or exit) (Bargmann and Horvitz, 1991). 6Interaction between food detection and egg-laying circuit. 7Avoidance (copper, cadmium). ASE has a minor role (Sambongi et al., 1999). 8 Avoidance (SDS) by ASH neurons. Phasmid neurons antagonize this avoidance behavior (Hilliard et al., 2002). 9Positive chemotaxis to water-soluble attractants (ASE, ASG, ASK, ASI: lysine; ASE, ASG, ADF, ASI: cAMP, biotin, Na+, Cl–). ASJ, ADF, ASI, ASG, ASK have minor roles (Bargmann, 2006; Bergamasco and Bazzicalupo, 2006). 10Avoidance of volatile repellents (octanol, 2-nonanone). ADL has a minor role. 11Positive chemotaxis to volatile attractants (AWC: benzaldehyde, butanone, thiazole, isoamyl alcohol; AWA: diacetyl, pyrazine). 12Touch receptor neurons that function in avoidance response to gentle body touch. Activation of this circuit also resets defecation cycle and suppresses pharyngeal pumping, foraging head movement, and egg-laying. The sensory mechanotransduction channel is formed by MEC-4/MEC-10/MEC-6. 13Detect nose touch. IL1 and OLQ; head withdrawal response to dorsal or ventral nose touch. ASH, FLP, and OLQ; reversal of movement in response to head-on collision. 14Detect harsh body touch, e.g., with a platinum wire (O’Hagan and Chalfie, 2006). 15Motor neuron stretch receptors. May be sensing body posture and tension generated along the body by muscles (White et al., 1986; O’Hagan and Chalfie, 2006). The sensory mechanotransduction channel is hypothesized to be formed by UNC-8/DEL-1/MEC-6. The signal may directly translate into localized changes in motor activity. 16Long, thin tailspike is thought to be a large sensory organ without the sheath and socket cells that characterize normal sensilla. May be sensing flexion of tail tip (Bird and Bird, 1991). 17Putative mechanosensory. 18Muscle may also function in stretch sensation through its own stretch receptor complexes that contain UNC-105 (Jospin et al., 2004). 19Avoidance (quinine). t Involved in navigation of movement (control of omega turns, reversals, sinusoids, etc.) through AIB and AIY interneurons (Gray et al., 2005). 20Control of life span (Alcedo and Kenyon, 2004; Bargmann, 2006). 21Involved in aggregation behavior (Rogers et al., 2006). 22Contains unexposed ciliated endings in the lips. Putative harsh touch sensor in the head. 23AFD is the major thermosensor while AWC is supportive (Mori and Ohshima, 1995; Kuhara et al, 2008; Ohnishi et al, 2011). 24(Chatzigeorgiou et al., 2010; Liu et al., 2012). 2.3 Motor Neurons and the Motor Circuit The locomotory behavior repertory of C. elegans includes "crawling" on solid surfaces and "swimming/thrashing" in liquid media. A total of 113 of the 302 C. elegans neurons belong to the motor neuron category, and they control crawling and swimming behaviors as well as the motility of the alimentary and reproductive systems. Of these 113, 75 innervate 79 body wall muscles posterior to the head (16 neck and 63 body muscles) and belong to eight distinct classes (AS, DA, DB, DD, VA, VB, VC, and VD) (NeuroFIG 6, NeuroFIG 7 and NeuroFIG 8). A- and B-type motor neurons (VA, VB, DA, DB, AS) are cholinergic and stimulatory. D-type motor neurons (VD, DD) secrete γ-aminobutyric acid (are GABAergic) and are inhibitory and strictly post-synaptic to other motor neurons. VC motor neurons express several transmitters and their primary targets are vulval muscles. VA, VB, VC, and VD classes innervate ventral muscles, whereas DA, DB, DD, and AS classes innervate the dorsal muscles by sending commissures to the dorsal side (White et al., 1976, 1986). NeuroFIG 6: VNC motor neurons and locomotory circuit. A. Neuronal control of locomotion during sensory and exploratory behaviors. (Left panel) The forward locomotion of the animal is interrupted by occasional turns and brief reversals. Omega turns result in an approximately 180°change in the direction of movement and usually follow a reversal. They can be spontaneous during exploration or induced by aversive stimuli. In the circuits that lead to reversals and turns, the dotted arrows indicate polysynaptic input. (Right panel) Mechanosensory reflex circuit (escape circuit). Five mechanosensory neurons (pink) that detect touch stimuli synapse onto command interneurons (red). These, in turn, synapse onto motor neurons (purple) responsible for forward (Fo) and backward (Ba) locomotion, leading to rapid withdrawal from the stimulus. Spontaneous forward motion can be initiated by a head motor nervous system, which is partially independent of the command interneurons (Chalfie et al., 1985; Zheng et al., 1999). DVA is a stretch-sensitive neuron with input to command interneurons and has a role in maintenance of the overall activity of the circuit (Li et al., 2006). The neuronal circuit that controls locomotion has been dissected into two parts by laser-ablation studies of command interneurons; PVC and AVB are primarily required for promoting forward movement, and AVA, AVD, and AVE are for backward movement (Chalfie et al., 1985). AVB makes gap junctions, and PVC makes chemical synapses with B motor neurons, which drive forward motion. AVA and AVD synapse, chemically and electrically, with class A motor neurons, which drive backward motion (A motor neurons also receive input from AVE in the anterior half of the body). Within the mechanosensory reflex circuit, ALM makes gap junctions to AVM in the NR, and ALM and AVM make gap junctions to AVD, which responds to touch stimuli applied to the anterior part of the animal (Driscoll and Kaplan, 1997). At hatching, ALM works by itself through AVD, and in late larval stages AVM is added into the circuit. PLMs make gap junctions to PVC, which is important for the posterior touch response. Touch neurons activate one circuit while inhibiting the other; ALM and AVM form inhibitory chemical synapses onto PVC, and PLM forms inhibitory chemical synapses onto AVD, thus preventing inadvertent opposite locomotion in the reflex cycle. This circuit also receives input from head mechanosensory receptor neurons (not shown). B. The A motor neurons control backward locomotion and B motor neurons control forward locomotion. D motor neurons, which receive synapses from A and B motor neurons and function as cross-inhibitory on the body wall muscles, are required for both forward and backward locomotion. On the dorsal side, VDs are exclusively post-synaptic, receiving input from DA, DB, and AS neurons as corecipients at neuromuscular junctions (NMJs) (dyadic synapse). On the ventral side, VD neurons are presynaptic to body wall muscle. DDs are exclusively post-synaptic on the ventral side, where they receive input from VA, VB, and VC neurons as corecipients at NMJs (dyadic synapse). DDs are predominantly presynaptic to body wall muscle on the dorsal side. The synaptic zones for the members of each class do not overlap, creating a clearly defined fate map of neuromuscular activity for each class (White et al., 1976). VC neurons are an exception to this rule. Active zones of members of different classes overlap; however, the transition regions among members are not generally the same for every class (White et al., 1976; Von Stetina et al., 2006). Neurons of a given class, except for VA, are electrically coupled to one another via gap junctions in both the VNC and DC. Similarly, muscle cells in each row of a muscle quadrant are also electrically coupled to their neighbors. The boxed model shows how reciprocal inhibitors (DD, VD) receive inputs diametrically opposite to their zone of innervation, so that contracting muscle quadrants (+) are matched by relaxing quadrants (–) on the opposite side of the body. (S) Synapse-free stretch-sensitive regions; (vm) vulval muscle; (green ovals) muscle; (red lines) interneurons; (black arrows and arrowheads) excitatory chemical synapses; (T-shaped lines) inhibitory chemical synapses; (straight lines with bars on each side) gap junctions. C. Schematic representation of positions of motor neurons between RVG and PAG along the VNC. (Based on White et al., 1976, 1986.) NeuroFIG 7: Longitudinal nerve tracts and commissures in the body. Longitudinal nerve tracts and commissures in the body. Excluding the VNC and DC, the longitudinal tracts have twofold symmetry (cf. NeuroFIG 2A&B). Excretory canal-associated nerves mark the midline on both sides. There are no cell bodies within the DC. VNC motor neurons, including those that send circumferential commissures to the DC, are indicated on the top panel, whereas the commissures themselves are marked on the bottom panel. The majority of the commissures run on the right side of the body. The ventral hypodermal nuclei positions (beige ovals between the motor neurons, numbered 2–10) are also shown in the top panel. PLM and PLN processes are located on the ventral side of the lateral hypodermal ridges, whereas ALM and ALN processes are located on the dorsal side of the lateral hypodermal ridges. Sublateral cords run under the body wall muscles. SDQ processes join the dorsal sublateral cords, and PLN processes travel into the ventral sublateral cords. (Bottom left inset) RVG (see NeuroFIG 8); (bottom right inset) tail ganglia (see NeuroFIG 8) that limit the VNC on anterior and posterior sides, respectively. (Based on White et al., 1986.) NeuroFIG 8: Location of body commissures in the head, neck and tail regions. A. The anteriormost body commissures belong to DB1 and VD1 neurons, which run on the right side. The DB1 commissure travels from the ventral side to the DC around the posterior of the pharyngeal procorpus (out of view to extreme left of panel). The VD1 commissure is located at the level of the terminal bulb of the pharynx. Slightly posterior to the VD1 commissure, processes of DD1, VD2, DB2, and DA1 travel to the DC. At the level of VD2 neuron soma, the RVG becomes continuous with the region containing the VNC motor neurons. B&C. DB1 processes and commissure. Left lateral (B) and right lateral (C) views. DB1 has both anteriorly and posteriorly directed processes within the VNC. The posterior process ends in the anterior body, and the anterior process travels to the level of pharyngeal pro-corpus, where it makes a dorsal turn and reaches the DC via a right-sided commissure. The DC process then travels posteriorly past the terminal bulb and terminates at a variable distance within the anterior body (S. Fields, pers. comm.). Epifluorescent images of transgenic animals expressing yellow fluorescent protein (YFP) driven by a 7-kb hum-2A promoter in the DB1 neuron, some other neurons, and the amphid socket (AmSo) cells. (Image source: S. Fields.) D. Schematic rendition of the nerve cords and commissures in the tail tip (also see NeuroFIG 18), left lateral view. The posteriormost body commissure belongs to AS11 and extends on the right side. The DA8 process travels into the DC. The PDB motor neuron process travels to the posterior through the right-side lumbar commissure, extends along the right lumbar ganglion, and reaches near the tail tip before making a dorsal turn and extending into the DC. Posterior processes from PLNs, ALNs, PHCs, and PVR (on the right side) extend straight into the tail tip. The AVG neuron process traverses the body in the VNC, reaches the left lumbar ganglion via the left lumbar commissure, and extends into the tail tip.
On solid surfaces, during exploratory behavior, the forward locomotion of C. elegans is interrupted with occasional turns and reversals that occur at predictable frequencies (NeuroFIG 6A) (Gray et al., 2005). In response to noxious stimuli, including touch, C. elegans escapes the stimulus by locomotory behavior involving similar turns and reversals or accelerated forward motion. When touched at the anterior body, the animal moves backward (reversal motion) and when touched at the posterior body, the animal moves forward (initiates forward motion or accelerates). When placed in a liquid medium, the animal reverts to a swimming behavior. The frequency of undulations in swimming is more rapid than during crawling, and the waveform of swimming worms is C shaped, as opposed to the S shape of crawling (Croll, 1975; Faumont et al., 2005). It is hypothesized that these two behaviors result from different patterns of neural activity. The VNC neurons regulate the characteristic undulatory movement of the animal, which involves alternate contraction of the dorsal and ventral longitudinal muscle rows. These motor neurons synapse onto either both dorsal or both ventral muscle quadrants, thereby restricting the body’s flexures to the dorsoventral plane, creating sinusoidal waves as the animal lies on its lateral side on the substrate. When the dorsal muscles are activated, the ventral muscles are reciprocally inhibited and vice versa. Bending against the substrate results in forward locomotion as a result of propagation of sequential contraction and relaxation waves passing backward along the body. D-type motor neurons have processes that are post-synaptic corecipients at the dyadic NMJs of stimulatory (A- or B-type) motor neurons, and the ventral D and dorsal D neurons work as reciprocal cross-inhibitors. Their GABAergic synaptic outputs are onto diametrically opposite muscles, so that when a ventral or dorsal muscle group is activated by a cholinergic motor neuron, the opposite group of muscles is inhibited and relaxed (NeuroFIG 6) (White et al., 1978; McIntire et al., 1993). D-type motor neurons are most important for resetting the animal’s posture, for example, when reversing direction or initiating rapid movement (Jorgensen and Nonet, 1995; Jorgensen, 2006). In response to a touch, an animal that lacks GABA input shrinks due to unopposed contraction of both dorsal and ventral muscles. Once an animal gets moving, GABA input does not interfere with wave propagation; however, it does affect the amplitude of the body waves. Movement in either forward or reverse directions is regulated by signals from specific classes of command interneurons (NeuroFIG 6A). Forward motion is promoted by input from AVB and PVC interneurons onto DB and VB neurons, whereas backward motion is promoted by input from AVA, AVD, and AVE interneurons onto DA and VA neurons (NeuroFIG 6) (Chalfie and White, 1988; Driscoll and Kaplan, 1997; Von Stetina et al., 2006). Synaptic innervation of motor neurons by command interneurons occurs throughout the length of the VNC. Command interneurons establish the direction of locomotion, but are not thought to be involved in wave propagation down the length of the animal (Jorgensen and Nonet, 1995). It is currently unclear which neurons are involved in wave propagation, although proprioceptive inputs are thought to have a role. The command interneurons are not equivalent because ablation of AVA or AVB produces uncoordinated animals (after a bout of forward or backward motion, animals kink while trying to reverse their direction) that are touch responsive, whereas ablation of PVC or AVD mainly abolishes the touch-mediated locomotory responses, but does not result in any change in spontaneous locomotion (Chalfie et al. 1985). The members of each class of body motor neurons are evenly distributed along the length of the ventral cord between the retrovesicular ganglion (RVG) and preanal ganglion (PAG). They create a longitudinal, synaptic fate map onto the body muscles (NeuroFIG 6C, NeuroFIG 7 and NeuroFIG 8). Within each class of motor neurons there is little or no overlap in the output regions of adjacent members (White et al., 1976). The cell bodies of motor neurons are covered by the hypodermal basal lamina and lie on top of the ventral hypodermal ridge or are wedged between the ridge and the processes of the right tract of the VNC. Motor neurons are generated at two distinct developmental stages: first, around midembryogenesis and then, during the first larval stage (Sulston and Horvitz, 1977; Sulston et al., 1983). DA, DB, and DD are the only classes of motor neuron present in the VNC at hatching. They are born at midembryogenesis and simultaneously extend commissures to the DC. Command interneurons that make synapses onto them enter the VNC after motor neuron outgrowth is completed. During the L1 stage, DA and DB innervate dorsal muscles and DD innervates ventral muscles. DD dendrites receive input from DA and DB at dyadic synapses onto the dorsal muscle arms. After hatching, the other five classes (additional 56 motor neurons) are generated by 13 (W and Pn) blast cells (see Epithelial System - Hypodermis ). The anterior daughters of the first division of P cells (Pna) give rise to 53 of these (Sulston et al., 1983). The processes from these later-born cells insert themselves into the cord between existing fibers to establish contacts with appropriate command interneurons and muscle cells. After post-embryonic motor neurons are born, DD neurons reverse their synaptic polarity without undergoing any structural change in process placement (White et al., 1978). They rearrange their synaptic machinery to receive input from the nascent VA and VB motor neurons and send output to dorsal muscles. An additional excitatory class of neurons, SABVL/VR/D, innervates anterior ventral body muscles only in the L1 stage; after this stage, they function as interneurons. Unlike the body, the head of the animal is capable of making lateral movements as well as dorsoventral flexures, especially during foraging behavior. Head and neck muscles are innervated by about 11 classes of motor neurons in the NR in a complex pattern (see Somatic Muscle). Additional nerve–muscle contacts occur along the length of the sublateral cords (J. Duerr et al., unpubl.). Most axons in these nerve cords show periodic swellings filled with synaptic vesicles and sometimes have small presynaptic densities. The post-synaptic targets of these synaptic release zones are possibly the body muscles. The specialized motor neurons of the alimentary and reproductive systems that are associated with defecation and egg-laying muscles are discussed the Alimentary System - Rectum and Anus and Reproductive System - Egg-laying apparatus sections, respectively. 2.4 Sensory Neurons C. elegans explores its environment and moves to favorable surroundings by chemotaxis, thermotaxis, and aerotaxis and escapes from harmful and noxious stimuli by avoidance/escape behaviors. The perception of environmental cues, including mechanical stimuli, temperature, many water-soluble and volatile chemicals, noxious substances, ambient osmolarity, oxygen levels, pH, and light, is accomplished through 24 sensillar organs and various isolated sensory neurons (NeuroTABLE 1) (Bargmann, 2006; Bergamasco and Bazzicalupo, 2006). Sensillar neurons perform most of the sensory functions. However, some sensory functions, including oxygen sensation and mechanosensation, are performed by nonsensillar neurons. Each sensillum contains ciliated endings of one or more neurons and often two types of glia: the socket cells and the sheath cells. Except for posterior deirids and phasmids, all sensilla are located in the head (see Neuronal Support Cells and Introduction; IntroTABLE 1). Through the function of these neurons, C. elegans navigates thermal, chemical, and oxygen gradients by modulating the probability of its turning behavior and speed of movement on a solid surface. Turning can be produced either by a reversal of movement followed by resumption of forward movement in a new direction or by omega turns in which the animals curl their whole body so that their heads get close to or even touch their tails before starting to move forward (NeuroFIG 6) (Pierce-Shimomura et al., 1999). Alternatively, the animal can accelerate its forward-directed movement after receiving a sensory signal. 2.4.1 Mechanosensation Mechanical stimuli, including gentle touch along the body (e.g., with a soft hair), gentle touch to the nose, harsh touch along the body (e.g., with a wire), and tapping of the culture plate, are perceived through touch receptors and proprioceptors that fall into three classes according to their cytoskeletal specialization: (1) mechanoceptors with ciliated sensory endings; (2) touch receptor neurons containing large-diameter, 15-protofilament microtubules (also called MT cells); and (3) neurons with processes containing synapse-free stretches and undifferentiated cytoskeletons (NeuroTABLE 1) (Herman, 1995; Driscoll and Kaplan, 1997; Syntichaki and Tavernarakis, 2004; Goodman, 2006; O’Hagan and Chalfie, 2006). Mechanociliary neurons display features important for sensing any mechanical deflections over the worm’s surface; IL1, CEP, OLL, OLQ, ADE, and PDE cilia terminate embedded within the cuticle, and all of them except for IL1 are anchored in this cuticle by small electron-dense nubbins. Additionally, the distal sections of ADE, PDE, OLL, and CEP cilia contain an amorphous, dark, microtubule-associated material (TAM) that is also found in mechanocilia of other species. IL1 cilia contain a dark-membrane-attached disc at their tips. All mechanosensory stimuli lead to avoidance responses in the hermaphrodite. Mechanosensory neurons detect force through mechanically-gated ion channels which produce touch- or stretch-evoked currents. These channels are generally formed by two protein superfamilies; the TRP channels which are nonspecific cation channels composed of subunits with six transmembrane α helices, and heterotrimeric DEG/ENaC channels which are permeable to sodium and sometimes to calcium (Arnadottir and Chalfie, 2010; Bounoutas and Chalfie, 2007; Kahn-Kirby and Bargmann, 2006). The C. elegans genome encodes 28 predicted DEG/ENaC proteins and 23 predicted TRP proteins(Goodman & Schwarz, 2003). Gentle (low threshold) body touch. A gentle stroke of the animal’s body with an eyelash is sensed by six touch receptor neurons (NeuroFIG 9 and NeuroFIG 10). The touch-response circuit additionally involves 6 interneurons and 69 motor neurons (Chalfie et al., 1985; Goodman, 2006). The processes of touch receptor neurons act both as dendrites receiving the touch stimulus and as axons carrying the signal to downstream neurons. If the animals are touched on the posterior half of the body, they either initiate or accelerate forward motion. If the stimulus is applied on the anterior half of the body, animals reverse and move backward. These two sensory fields (anterior and posterior) are defined by the arrangement of the touch receptor processes along the body axis. The ALM (anterior lateral MT cell) pair and AVM (anterior ventral MT cell) respond to stimuli applied on the anterior half, whereas the PLM (posterior lateral MT cell) pair sense those applied on the posterior half. The PVM (posterior ventral MT cell) is suggested to contribute to the response, although it cannot initiate a discernible touch response by itself. Animals that lack touch receptor neurons do not respond to light touch but are still capable of sensing harsh body touch (Chalfie and Sulston, 1981). NeuroFIG 9A-C: Mechanosensory neurons that sense gentle touch. A&B. Fluorescent micrographs of an adult animal expressing the reporter gene mec-4::GFP in touch receptor neurons. A. Left lateral view. B. Ventral image taken from the dorsal side. The unpaired AVM and PVM are located sublaterally on the right anterior ventral side and left posterior ventral side of the animal, respectively. Their processes enter the VNC via commissures and run in an extreme ventral position near the cuticle within the VNC. The PVM process ends in the anterior body. The AVM process terminates slightly posterior to the anterior bulb of the pharynx; however, at about 1–2 μm anterior to the excretory pore, it sends off branches that enter the NR on both sides. The ALM cell bodies are located laterally in the midbody where PLM processes end. The process of each ALM runs near the dorsal edge of the lateral hypodermal ridge on each side, in close association with the process of ALN. ALM processes send off branches about 10 μm anterior to the excretory pore. These processes enter the NR subdorsally, end shortly after they meet, and make gap junctions with the branches of the AVM (arrowheads). ALM and AVM make synapses with command interneurons within the NR. The PLM cell bodies are situated in the lumbar ganglia; their anterior processes run near the ventral edge of the lateral hypodermal ridges, in close association with the processes of PLN. The PLM processes turn ventrally and enter the VNC near the vulva (arrows). VNC branches terminate after a short distance, whereas the main process terminates within midbody region, adjacent to where ALM is located. (NR) Nerve ring; (blue dotted line) position of vulva. Magnification, 400x. (Strain source: M. Driscoll.) C. Graphic rendition of touch receptor neurons as seen from the left side. Stroking the animal’s body with an eyelash generates a gentle touch stimulus that stimulates the touch receptor neurons and initiates an avoidance response. (Gray dotted line) Lateral midline; (gray oval) position of the CAN neuron, depicted for position comparison. NeuroFIG 9D-J: Mechanosensory neurons that sense gentle touch. D. At the time of hatching, lateral touch neuron processes are located adjacent to the body wall muscle (left panel). During larval development, processes of lateral touch neurons become embedded in the hypodermis just beneath the cuticle (right panel). An electron-dense ECM, called mantle, surrounds the touch receptor processes and attaches them to the body wall. Mantle ECM is secreted by the touch receptor neurons as well as by the surrounding cells. The amount of mantle varies along the length of the process. Touch receptor processes are filled with 15-protofilament MTs. (ER) Endoplasmic reticulum. (Image source: N501 [Hall] S3 N517 [right panel]; N2L1C [MRC] A1082-19 [left panel].) E. Touch neuron processes form attachments to the cuticle at intervals through fibrous organelles (FO), structures similar to those seen underlying muscle cells. Although these attachments were found not to be essential for touch sensitivity, they are thought to ensure that a very slight deformation of the process gets transduced by the receptor (Vogel and Hedgecock 2001; Goodman and Schwarz 2003; Emtage et al. 2004). F&G. Mechanotransducing degenerin channel complex, made from the assembly of MEC-4, MEC-6, and MEC-10, a channel-associated protein (MEC-2), and collagen (MEC-5), colocalize in a punctate manner. These puncta of the mechanotransduction apparatus align with the cuticular annuli along the touch neuron process. H. Schematic representation of mechanotransduction complex. MEC-4 and MEC-10 form the transduction channel, which is attached via MEC-2 to 15-protofilament MTs. MEC-6 interacts with the channel proteins to regulate channel activity. The complex is suggested to be linked to the ECM and cuticle (Cu) through fibrous organelle-like structures. Mechanical deflection of the ECM mantle relative to the MT bundle may gate the transduction channels. (Based on Gu et al., 1996; Goodman and Schwartz, 2003.) I. A lateral touch cell process with 15-protofilament MTs (inset) is shown. The number of protofilaments in the MTs of touch cells may vary between 12 and 16. These MTs have an average outer diameter of approximately 16 nm. (Reprinted, with permission, from Chalfie and Thomson, 1982.) J. In C. elegans, all singlet MTs, other than those in touch cells, have 11 protofilaments. Shown is a VNC neuron process with 11 protofilament MTs (inset). These MTs have an average outer diameter of approximately 13 nm. (Reprinted, with permission, from Chalfie and Thomson, 1982. ©Rockefeller University Press.) NeuroFIG 10A: Sensory neurons that sense nose touch, osmotic pressure, texture, and harsh touch. In all panels, only the cells on the left side are shown. A. (Left panel) Graphic rendition of the left-side FLP (top) and IL1, OLQ, and ASH (bottom) neurons. The avoidance response to the head-on nose touch is mediated by ASH, OLQ, and FLP neurons. IL1 and OLQ neurons mediate the head withdrawal to gentle touch to the ventral or dorsal side of the nose. (Right panel) The FLPL branching pattern in an adult animal is seen at two different focal levels, lateral view. Epifluorescent micrographs of an animal expressing the mec3::GFP transgene. Closer to the middle plane (top), the two main branches (arrows) are seen to be coming out of the cell soma. The posteriorly directed process enters the VNC via the deirid commissure and terminates after the excretory pore (asterisk indicates processes of AVM and ALM, which also express this transgene). The anterior FLP process travels to the tip of the nose and gives off branches along its way. The extensive branching pattern (bottom) is made at the level of the dorsal and ventral muscle quadrants (arrows). One of the branches terminates in a ciliated ending close to the lateral inner labial sensillum. Magnification, 400x. (Strain source: M. Chalfie.) NeuroFIG 10B-E: Sensory neurons that sense nose touch, osmotic pressure, texture, and harsh touch. B. Dopaminergic neurons that detect stimulus texture. Each neuron has a ciliated ending either in the head or midbody. (Top) Schematic rendition, lateral view. (Bottom) DIC image of the posterior lateral side of the body. The nuclei of the neurons in the left lateral ganglion are seen close to the excretory canal (arrow). Magnification, 600x. C. Graphic rendition of neurons required for perception of harsh touch to the body (PVD) and tail (PVC), lateral view. D&E. PVD neurons. D. (Top panel) Adult, ventral-lateral view. PVD neurons have multiple short branches (arrowheads) that arise at the level of the muscle quadrants (arrow). (Bottom panel) L1 animal, left lateral view. Although the three main processes are already formed (arrowheads), few branches are seen. E. (Left panel) Adult, lateral view. PVD processes terminate around the region of the posterior bulb of the pharynx (arrowhead). (Right panel) Adult, lateral view. Multiple branches arise from the posteriorly directed PVD process (arrows), which continue to the tail region (arrowhead). All are epifluorescent images of transgenic animals expressing the ser2prom3::GFP reporter in PVD neurons on a roller background. Magnification, 400x. (Strain source: O. Hobert.) ALM and PLM cells are born during embryogenesis. ALM cells migrate posteriorly, a process that is completed before the elongation stage of the embryo (Sulston et al., 1983; Chalfie, 1993). In newly hatched larvae, the processes of these touch cells are located between the lateral hypodermis and the adjacent muscle quadrant. At about 12 hours post-hatching, they become engulfed by the adjacent hypodermis (Chalfie, 1993). Two other touch receptor neurons, AVM and PVM, are born post-embryonically about 9 hours after hatching at 20°C. Their processes run anteriorly within the VNC at its extreme ventral edge (NeuroFIG 5). Each touch neuron process is 400–500 μm long in the adult and is filled with large-diameter (30 nm), 10- to 20-μm-long, 15-protofilament MTs that overlap and bundle together through cross-links (Chalfie and Thomson, 1979, 1982). The tubulin dimers MEC-12 (α-tubulin) and MEC-7 (β-tubulin) coassemble into these 15-protofilament structures (Fukushige et al., 1999). At hatching, ALM and PLM cells contain fewer and shorter MTs. By 12 hours, MTs start to increase in number and length and, by 36–48 hours, adult levels are reached (Chalfie and Thomson, 1979, 1982). The touch receptor neurons also transduce the plate-tap response, which is considered to involve a nonlocalized touch stimulus. In the tap response, signals from the anterior touch circuit (the producer of backward movement) tend to override those from the posterior one, causing animals to reverse direction or move backward in response to a tap to the culture plate. This preference becomes especially strong at L4–adult transition (approximately 46–51 hours post-hatching) when the late-developing AVM becomes connected to the anterior touch circuit by forming an inhibitory connection to the AVB interneurons (Chalfie and Sulston, 1981; Walthall and Chalfie, 1988; Chiba and Rankin, 1990). Touch sensation modifies other behaviors of the animal; for example, gentle body touch regulates pharyngeal pumping and egg-laying and resets the defecation cycle. These responses may be elicited by the synapses between the touch neurons and CEPs, deirid neurons, HSN motor neurons, and RIP interneurons (Syntichaki and Tavernarakis, 2004). Harsh (high threshold) body touch. In the absence of all touch receptor neurons, the animal still retains the ability to respond to harsh touch along the body (e.g., with a wire), and this response can be eliminated by killing the PVD cells (recent results suggest ALM neurons also sense harsh touch (Chatzigeorgiou et al., 2010)). Hence, PVD neurons, which are presynaptic to command interneurons AVA and PVC, are proposed to be the mechanoceptors for harsh body touch (Way and Chalfie, 1989). In adult animals, PVD neurons show extensive branching along the body wall, from the tail to the neck of the animal, covering dorsal and ventral territories (NeuroFIG 3 and NeuroFIG 10) (Halevi et al., 2002). Multiple short branches arise from the main branches at the level of the muscle quadrants and these branches give rise to further branches subventrally and subdorsally. The molecules needed for mechanotransduction of harsh touch are not well known (O’Hagan and Chalfie, 2006). mec-3 mutant animals, in which PVD neurons do not differentiate properly, retain the ability to respond to harsh touch to the head and tail (Way and Chalfie, 1989; Tsalik et al., 2003; O’Hagan and Chalfie, 2006). A harsh touch defect in the tail is seen in the absence of PVC neurons, which may be sensing the stimulus directly or indirectly through other neurons (NeuroFIG 10C). Harsh (high threshold) head/nose touch. Three classes of neurons, FLP, ASH, and OLQ, form ciliated endings in the nose, which transduce head-on nose touch stimuli that results in reversal of movement (NeuroFIG 10) (Kaplan and Horvitz, 1993). FLP neurons have a similar branching pattern to PVDs in the head (topologically they complement; where PVD branches end in the neck, FLP branches start) and act together with ASH neurons to sense harsh mechanical stimuli to the head (Albeg et al., 2011; Chatzigeorgiou and Schafer, 2011). OLQs may enhance this mechanoreception (NeuroFIG 10A). ASH and FLP neurons are coupled to the locomotion circuitry via gap junctions and chemical synapses made onto AVA, AVB, and AVD interneurons. Gentle (low threshold) nose touch. Two classes of neurons, OLQ and IL1, function in aversive head-withdrawal reflex and suppression of lateral foraging movements of the head in response to gentle touch on the ventral or dorsal tip of the nose (Hart et al., 1995). IL1 and OLQ synapse onto NR motor neurons, and IL1 makes direct synapses onto head muscles. OLQ may also function in mechanosensory feedback for foraging, as the rate and amplitude of foraging in unstimulated animals is affected in OLQ-ablated animals. FLP neurons also respond to gentle nose touch and activate an escape behavior (Chatzigeorgiou and Schafer, 2011). OLQ and CEP neurons indirectly facilitate gentle nose touch responses in the FLP head nociceptors via the RIH interneuron which acts as the integrating neuron of this circuit hub(Chatzigeorgiou and Schafer, 2011). Texture sensation. C. elegans can sense mechanical attributes of the surface material on which it navigates through the function of dopaminergic CEP, ADE, and PDE neurons (NeuroFIG 10) (Sawin et al., 2000). The capability to distinguish texture (e.g., small, round objects) helps animals to detect food in their environment, in addition to olfactory cues, and causes slowing of locomotion (food-induced slowing response). Proprioception. Worms may sense changes in stretch and tension within their own bodies, especially during locomotion. Some neuron processes with morphologically nonspecialized, synapse-free, bare-wire portions are thought to transduce proprioceptive stimuli. Such properties have been hypothesized for many neurons, including the A- and B-type motor neurons, PHC, some pharyngeal neurons, and male tail neurons (NeuroFIG 6) (Hall, 1977; Sulston et al., 1980; Albertson and Thomson, 1984; Hall and Russell, 1991; R. Lints and D.H. Hall, unpubl.). Some of these may function to sense the degree of bending during undulatory movement, providing sensory feedback about the worm’s body posture and coordinating the degree and timing of alternating contractions and relaxations of muscles (White et al., 1986; Tavernarakis et al., 1997). A similar proprioceptive property has been proven for the DVA neuron, in which stretch sensitivity is transduced by the trp-4 membrane channel (Li et al., 2006). The DVA axon travels from its cell body in the tail anteriorly to the NR via the VNC, but it is not known to show any specializations by TEM that mark its stretch-sensitive portion. PVD may have a role in proprioception, as ablation of PVD leads to defective posture (Albeg et al., 2011). PVD and DVA neurons are presynaptic to both forward and backing command interneurons and provide input to both anterior and posterior touch circuits to maintain overall activity of the circuits. Animals lacking these neurons respond to tap stimulus with diminished forward accelerations and reversals, and mutation of the trp-4 channel or laser ablation of DVA gives rise to animals with body bending defects (Wicks et al., 1996; Driscoll and Kaplan, 1997; Li et al., 2006). Body wall muscles may also sense the degree of stretch within them and modulate the contractions required for organized locomotion (Liu et al., 1996). Putative “proprioceptive” endings in the pharynx are fastened by AJs or hemi-AJs to the pharyngeal cuticle (I1, I2, I3, I6), pharyngeal muscle specializations near the lumen (M3, NSM), or a muscle cell soma (I5) (Albertson and Thomson, 1976). Physiological experiments support that a few of these pharyngeal neurons may be stretch sensitive (Avery and Thomas, 1997). 2.4.2 Nociception Nociception is the ability to recognize toxic and harmful components in the environment that allows for avoidance and survival. For C. elegans, aversive cues include mechanical stimuli (both light and harsh touch), certain odorants and toxic chemicals, high osmotic strength, acidic pH, extremes of heat and cold (see thermonociception below), and certain light wavelengths (Culotti and Russell, 1978; Tobin and Bargmann, 2004). Many of the chemicals that are noxious for C. elegans are toxic or bitter for other animals as well, including sodium dodecyl sulfate (SDS), quinine, and heavy metals such as copper (Sambongi et al., 1999; Tobin and Bargmann, 2004). It should be noted that animals in diapause are much more stress-tolerant, including heat-shock conditions (Wittenburg and Baumeister, 1999, see Dauer chapter). ASH neurons are polymodal nociceptors that detect nose touch, high osmotic strength (high concentration of salts or sugars), acidic pH, quinine and other bitter compounds, heavy metals, and aversive odors such as 2octanone, octanol, and benzaldehyde (NeuroTABLE 1). ASH neurons have cilia exposed to the outside and generate a rapid escape response in the form of reversal and turning upon encountering noxious stimuli (NeuroFIG 6) ( et al., 1986; Troemel et al., 1997; Hart et al., 1999). All ASH-mediated sensory behaviors require the TRPV channels OSM-9 and OCR-2 (Tobin et al., 2002). The diverse array of nociceptive cues sensed by ASH neurons generate distinct amplitudes and patterns of glutamate release from these neurons onto the target command interneurons that allow separable behavioral responses (Mellem et al., 2002). 2.4.3 Chemosensation and Odorsensation C. elegans can detect and discriminate a wide range of chemical compounds, including water-soluble chemicals (chemosensation or gustatory sensation) such as anions, cations, cyclic nucleotides, biotin, and amino acids and volatile chemicals (odorsensation or olfactory sensation) such as alcohols, aldehydes, ketones, esters, pyrazines, thiazoles, and aromatic compounds (Bargmann and Mori, 1997; Mori, 1999; Bargmann, 2006). There are 32 chemo/odorsensory neurons that fall into 14 classes. Of these, 22 are paired neurons of the amphid sensilla, four are paired neurons of the phasmid sensilla, and six are IL2 neurons of the inner labial sensilla (NeuroTABLE 1; see Neuronal Support Cells). Most of the individual amphid neurons detect either water-soluble or volatile chemicals and direct either attraction or aversion, although lower concentrations of certain chemicals may be sensed as attractive, whereas higher concentrations may become repellent. A few neurons may sense both attractive and aversive cues (NeuroTABLE 1) (Bargmann and Horvitz, 1991; Bargmann et al., 1993; Troemel et al., 1997). The ADF, ASE, ASG, ASI, ASJ, and ASK neurons mediate chemotaxis to water-soluble attractants. Among these, ASE seems to be the main sensor, with others having weaker roles. ASE is also unique because the two ASE neurons have distinct functions; the ASER preferentially detects chloride and potassium ions, whereas the ASEL preferentially senses sodium ions (Pierce-Shimomura et al., 2001). ASH neurons are the main nociceptors and mediate avoidance from water-soluble and volatile cues. ASH is complemented by other amphid neurons in these functions; ADL neurons contribute to osmosensation and avoidance from octanol, copper, and cadmium, whereas ASK and ASE contribute to avoidance of SDS and to cadmium and copper, respectively (Sambongi et al., 1999; Hilliard et al., 2002). ASJ neurons participate in formation and recovery by detecting dauer-inducing (dauer pheromone) and dauer-suppressing (food) signals in different developmental stages. ADF, ASI, and ASG function to inhibit dauer formation under favorable conditions (Bargmann and Horvitz, 1991). The three “wing” cells AWA, AWB, and AWC sense volatile chemicals, and each neuron is preferentially linked to a particular behavioral response (Wes and Bargmann, 2001). Whereas AWC and AWA mediate odortaxis to volatile attractants, AWB detects aversive odorants important for long-range escape behavior. As described above, C. elegans lies on either of its sides and moves either forward or backward using a sinusoidal-like undulation by alternately contracting its body wall muscles along the ventral and dorsal surface. Most of the time, the animals simply move forward (smooth runs), but this forward locomotion is occasionally interrupted by a number of processes such as omega-turns, pirouettes and gentle turning. During an omega-turn the worm makes a deep bend with the worm’s head often contacting its tail, before the animal returns to forward motion along a new heading. Pirouettes are a series of reversals with one or more omega-turns that allow the worm to make major re-orientations in its direction of movement. Gentle turns (steering) are generated when the worm gradually changes its heading by a biased head swing during forward locomotion. Pirouettes appear to occur randomly, while steering appears to be a more directional process. Chemotaxis is driven by gently steering up the gradient as the worm moves forward and by altering the probability of pirouette initiation by which runs toward lower concentration are interrupted, whereas runs toward the attractant are sustained, eventually biasing the locomotion toward the higher concentration of the chemical (Appelby, 2012; Pierce-Shimomura et al., 1999; Iino and Yoshida, 2009). 2.4.4 Thermosensation As a cold-blooded soil nematode, C. elegans can tolerate a limited temperature range (~12-27°C) at which it is both fertile and viable (Hedgecock and Russell, 1975). C. elegans can accurately detect temperatures within this range, and this is reflected in its thermotactic behavior. Following cultivation with food at temperatures ranging from 15°C to 25°C, it migrates to the cultivation temperature on a temperature gradient and continues to move isothermally at that temperature. In contrast, the animals disperse away from the temperature at which they were previously starved (Hedgecock and Russell, 1975; Mori, 1999). This thermal preference/avoidance behavior is plastic and can be reset to a new temperature associated with presence/absence of food within 2–4 hours of cultivation at that temperature. Through thermotactic behavior, C. elegans can escape unfavorable environments and regulate its position in the upper levels of soil, which may display large vertical and temporal temperature gradients. Behaviorally, C. elegans migrates towards its preferred temperature by modulating its turning rate and run length as a function of temperature change. Once it reaches within 3°C of its preferred temperature, it can fine-tune its tracking to 0.05°C differences by constantly reorienting its head movement (Ryu and Samuel, 2002; de Bono and Maricq, 2005) There are three thermosensors in C. elegans; the amphid AFD neurons (also called “finger” cells) are the major thermosensors (NeuroTABLE 1; see Neuronal Supportal Cells), while the amphid AWC and ASI neurons are supportive (Mori and Ohshima, 1995; Kuhara et al, 2008; Ohnishi et al, 2011; Beverly et al, 2011). AFD neurons have complex, brushlike structures at their dendritic ends that are completely embedded in the amphid sheath. Animals in which AFDs are killed are athermotactic. TAX-6 (calcineurin), three receptor-type guanylyl cyclases which function redundantly (GCY-8, GCY-18, and GCY-23), and cGMP-dependent TAX-2/TAX-4 cation channel have been shown to be involved in thermosensation in AFD (Kuhara et al., 2002; Inada et al., 2006). When tax-6 is mutated, animals display a thermophilic phenotype, whereas gcy-23, gcy-8, and gcy-18 triple mutants show a cryophilic or athermotactic phenotype. In AWC, heterotrimeric G-protein signaling and cGMP-dependent TAX-4 cation channel are involved. In the current model for thermosensation, the downstream AIY interneuron is bidirectionally regulated by AFD and AWC. Thermosensory information is transmitted from AFD and AWC to AIY through EAT-4/VGLUT-dependent glutamatergic neurotransmission. Glutamatergic signals from AFD inhibit AIY via activation of GLC3 (glutamate-gated chloride channel) and induce migration towards colder temperature. Glutamatergic signals from AWC, on the other hand, stimulate AIY to induce migration towards warmer temperature (Kuhara et al, 2008; Ohnishi et al, 2011). When AI Y are killed animals become cryophilic and migrate to colder temperatures than the cultivation temperatures, while ablation of AIZ neurons, which are the main postsynaptic target of AIY, makes animals thermophilic and induce them to migrate to warmer temperatures (Mori, 1999). C. elegans also reacts to noxious (extreme cold or hot) temperatures. A prolonged exposure at 30°C results in an induction of the heat-shock response and the animals cease egg-laying within a few hours (Lithgow et al., 1995), but resume reproduction if returned to lower temperatures (Aprison and Ruvinsky, 2014). Behaviorally, when they encounter a noxious heat source they respond with a reflexive withdrawal reaction (thermal avoidance response) (Liu et al., 2012; Wittenburg and Baumeister, 1999). PVD neurons in the body respond to acute cold shock, while AFD and FLP neurons in the head and PHC neurons in the tail sense noxious high temperatures (~35-38oC) (Chatzigeorgiou et al., 2010). This nociceptive heat response utilizes a different neural circuit than thermotaxis and the response of C. elegans to noxious high heat is modulated by glutamate and by the neuropeptides encoded in the flp-1 locus. Two channel protein families contribute to thermonociception in C. elegans in distinct neurons: the TAX-2/TAX-4 cyclic nucleotide-gated channels and thermal-gated TRPV channels (TRPA, TRPM and TRPV ion channel families are considered "thermoTRPs"; the gating of these channels by temperature is facilitated by chemical signals)(Hall & Treinin, 2011). Upon encountering noxious heat, TAX-2 and TAX-4 become activated in AFD neurons by cGMP which is mainly generated through the activity of GCY-12, but also to a lesser extent by GCY-8/18/23. In FLP and PHC neurons thermonociceptive signal transduction involves the OCR-2 and OSM-9 TRPV channels which can assemble into a heteromultimeric channel complex. PVD response to cold requires TRPA-1 channel (Chatzigeorgiou et al., 2010). 2.4.5 Light Sensation Light stimuli induce a photophobic, movement-reversal response in C. elegans. Recently, it has been found that this response peaks in the high-energy ultraviolet (UV) range (blue-violet) and the head sensory neurons are apparently not required for this behavior (Burr, 1985; K. Miller, pers. comm.). It is suggested that the response originates in the VNC, although the exact sensory mechanism is yet to be described. 2.4.6 Oxygen and Carbon dioxide Sensation C. elegans lacks a specialized respiratory system and uses diffusion for gas exchange. It can sustain a normal rate of metabolism between 2% and 21% ambient oxygen due to diffusion of oxygen to its tissues through the pseudocoelomic fluid, in which all tissues bathe (Van Voorhies and Ward, 2000). When cultivated under standard laboratory conditions, with a linear gradient from anoxia to atmospheric oxygen in the gas phase, C. elegans rapidly moves to an intermediate preferred oxygen concentration of between 7% and 14% oxygen, avoiding both high and low oxygen levels, although this response can be modified by environment and experience (Gray et al., 2004; Cheung et al., 2005; Rogers et al., 2006). In the wild, C. elegans lives close to decaying organic matter where it is exposed to an air/water interface with rapidly shifting oxygen tensions (0–21%) due to consumption of oxygen by microbes. Ambient oxygen levels may, therefore, be perceived as indicating the presence of food by this animal. Oxygen sensation is performed by a distributed network of neurons that includes AQR, PQR, and URX, possibly gcy-35-expressing SDQ, ALN, and BDU, and osm-9-expressing (nociceptive) ADF and ASH neurons (White et al., 1986; Gray et al., 2004; Chang et al., 2006). AQR, PQR, and URX may perform a head-to-tail oxygen comparison achieved through their positions along the body in close contact with the pseudocoelom because they are suggested to function to monitor the pseudocoelomic fluid, including its oxygen content (NeuroFIG 11) (Rogers et al., 2006). AQR is a right-sided neuron, derived post-embryonically from the QR blast cell; PQR is a left-sided neuron, derived post-embryonically from the QL blast cell. Both have ciliated endings. The AQR ending is free within the pseudocoleomic cavity, whereas the PQR ending lies close to the pseudocoelom, but is wrapped by the phasmid socket cell (see Neuronal Supportal Cells). URX cell bodies lie within the pseudocoelomic cavity. Similar to URX, AQR, and PQR neurons, SDQ, BDU, ALN, and PLN express soluble guanylate cyclases (sGC) that bind to molecular oxygen, consistent with a primary oxygen-sensing function for these AQR neurons. SDQs are also similar in lineage, morphology, and neural connectivity to the AQR and PQR neurons. Additionally, nociceptive ADF and ASH neurons may be modulatory or respond to oxygen directly. The output of the aerotaxis neuron network converges on AVA, the command interneuron responsible for generating backward motion and, hence, avoidance. The presence or absence of food modulates the basic aerotactic responses of hypoxia and hyperoxia avoidance. Modulation of hyperoxia avoidance is accomplished through the neuropeptide receptor NPR-1, the transforming growth factor-β (TGF-β)-related protein DAF-7, and serotonin production by the ADF neurons, whereas hypoxia avoidance seems to be mediated through a neuronal network that is independent of these pathways (Chang et al., 2006). In the wild, C. elegans inhabits rotting material which contains a broad range of CO2 levels, however as in other animals, high CO2 levels are toxic causing deterioration of muscle organization, reducing fertility and slowing development above 9% (Bretscher et al., 2008; Hallem and Sternberg, 2008; Sharabi et al, 2009). Thus, the animal typically shows an acute avoidance response to CO2 (especially well-fed animals) when CO2 level is above 0.5%. Animals also respond to changes in ambient CO2 levels. Primary CO2 sensors are AFD, BAG and ASE neurons (Bretscher et al., 2011). The signal pathway for CO2 response in AFD and BAG include the TAX-2/TAX-4 cGMP-gated heteromeric channel and the atypical soluble guanylate cyclases that also mediate oxygen responses in BAG. AFD neurons respond to increasing CO2 by a fall and then rise in Ca2+ and show a Ca2+ spike when CO2 decreases. BAG and ASE are both activated by CO2 and remain tonically active while high CO2 persists. The CO2 responses in AFD, BAG and ASE neurons do not habituate upon multiple exposures to CO2. The modulators of the CO2 -response include physiological state of the worm, the neuropeptide Y receptor, NPR-1, and calcineurin subunits, TAX-6 and CNB-1. NeuroFIG 11A&B: Neurons that sense ambient oxygen levels. A. Graphic rendition of the sensory neurons that function in aerotaxis, lateral aspect (Gray et al., 2004; Zhang et al., 2005). AQR is a right-sided neuron; PQR is a left-sided neuron. Additionally, nociceptive ASH and ADF neurons (not shown) might respond to oxygen. Of the neuron pairs, only left-sided members are shown. B. A transverse TEM image from the head region just posterior to the nerve ring. URX cell bodies have direct exposure to pseudo-coelomic fluid and its contents. They are placed dorsally between the dorsal ganglion and lateral ganglia; however, they do not belong to these ganglia and are not bounded by their basal laminae (BL). Similar to other neurons, URX are small cells with scant cytoplasm. Bar, 1 μm. (Image source: [MRC] N2U-A201-6.) NeuroFIG 11C-G: Neurons that sense ambient oxygen levels. C. DIC image, lateral view. URXR is positioned on the right dorsal side of the isthmus, adjacent to the posterior edge of the NR. Magnification, 600x. D. DIC image, lateral view. AQR is an unpaired neuron located on the right side, near the terminal bulb of the pharynx. Magnification, 600x. (Inset) Schematic representation of the placement of AQR and ADER cilia in the pseudocoelom and cuticle, respectively. The dorsal branches of ADER and FLP continue anteriorly on the lateral sides of the terminal bulb (arrows). Right anterior deirid commissure processes are omitted. E&F Epifluorescent images from an animal expressing the reporter gene gcy-32::GFP in oxygen-sensing neurons. E. URX axons enter the nerve ring subdorsally (arrowhead, right panel), whereas their dendrites travel anteriorly with the subdorsal labial process bundles, before terminating as nonciliated, flattened endings associated with the dorsal inner labial sensilla (left panel). The axon of AQR enters the VNC via the right-side deirid commissure (small arrow, right panel) and travels anteriorly before splitting posteriorly to the nerve ring. The AQR dendrite terminates in a cilium (large arrow) that is exposed to the pseudocoelomic space. Magnifications: right panel, 600x; left panel, 1000x. (Strain source: S. Yu and L. Avery/CGC.) F. PQR is an unpaired neuron situated in the left lumbar ganglion. Its anterior axon runs within the VNC, before it terminates slightly posterior to the vulva. Its posteriorly directed dendrite terminates with a cilium. Magnification, 600x. (Same strain as in E.) G. DIC image, left lateral view. The PQR nucleus is seen within the left lumbar ganglion posterior to the rectum. (a) Anus. Magnification, 600x. NeuroFIG 11H&I: Carbon dioxide-sensing neural circuit includes BAG neurons. H. Graphic rendition of BAG neurons. Lateral view B. Epifluorescent image from an animal expressing the reporter gene gcy-33::GFP in BAG neurons. Lateral view. Magnification, 600x. BAG neuron dendrite ending (inset). The position of the lips is marked by the dotted line.
2.5 Interneurons As in other organisms, interneurons comprise the largest group of neurons in the nematode. They function as information processors, receiving inputs from one or more classes of neurons and relaying outputs onto other neurons. They are suggested to compare and process sensory inputs in individual neuronal circuits and modulate the decision to execute a given motor program. They also function as circuit couplers where information from two or more circuits converge to establish circuit hierarchies. As an example, AVF, AVJ, and AVB interneurons link the neural networks for egg-laying and locomotion and function in temporal coordination of these two behaviors (Hardaker et al., 2001). 2.6 Polymodal Neurons Some C. elegans neurons perform more than one type of circuit function, including both motor and sensory functions or interneuron–motor neuron or interneuron–sensory neuron functions (White et al., 1986). Polymodal neurons are much more common in the male tail circuitry than anywhere else (Sulston et al., 1980; S.W. Emmons et al., unpubl.). M3 neurons of the pharynx have both motor and sensory functions. NSM neurons are both neurosecretory and motor neurons, and they may also have proprioceptive function (Albertson and Thomson, 1984). A- and B-type VNC motor neurons are suggested to be proprioceptive. IL1 neurons in the head perform mechanosensory, motor, and interneuron functions, whereas OLQ neurons are both mechanosensory and interneurons. RIM, SMB, SMD, RMD, RMH, and RMF classes of head neurons seem to be both motor and interneurons. AVL is a motor neuron with additional interneuron-type synapses. DVA is an interneuron that also functions as a stretch-sensitive sensory neuron. DVB is a motor neuron for enteric muscles and is also an interneuron. Alternatively, some neurons have multiple functions within one modality. ASH sensory neurons, for example, function as mechanosensory, osmosensory, odorsensory, and nociceptive, and ADLs are chemosensory, odorsensory and nociceptive. 2.7 Ganglia Most neuron cell bodies in C. elegans are grouped into ganglia that are typical of invertebrates (Chitwood and Chitwood, 1950; White et al., 1986; Hall et al., 2006). C. elegans ganglia contain clusters of cells but few or no synapses. All except the anterior ganglion are bounded by the basal lamina of the hypodermis. The neuron processes extend from each of these ganglia, traveling in longitudinal nerve bundles into various regions of synaptic neuropil, where they form chemical and electrical synapses. The most prominent neuropil regions are the NR, VNC, and preanal ganglion. In addition to the ganglia, many neuron cell bodies lie in tandem along the length of the VNC. A few other neuron cell bodies lie singly or in small groups along the lateral body wall or within the pseudocoelom (URX, CEPD). 2.8 Process Bundles Most neuron processes fasciculate into organized bundles (nerves or nerve cords) that may comprise as few as two or as many as 50 processes and run in parallel over long distances within the body (NeuroFIG 7 and NeuroFIG 8). Most of these processes run longitudinally along the body wall, except where they enter the NR. Most nerve cords are specialized to include limited functional groupings. For instance, the amphid nerves in the head and the phasmid nerves in the tail include only sensory dendrites and travel directly from sensory endings to related neuron cell bodies in local ganglia. Conversely, many neuron processes of the VNC, DC, and NR have mixed functions. The number and spatial arrangement of processes within the nerve tracts are essentially conserved between animals (White et al., 1976, 1983, 1986; Chalfie and White, 1988). Neighboring processes generally stay closely associated for long distances, and synapses are made en passant between adjacent processes. The neighborhoods, therefore, determine connectivity between neurons. Switching between neighborhoods, which most commonly occurs at the junctions of process bundles, increases the number of potential synaptic partners for a given neuron. The VNC is the major longitudinal nerve and splits posteriorly to the excretory pore into major (right side) and minor (left side) tracts that flank the ventral hypodermal ridge (NeuroFIG 5). In adult animals, the left VNC tract contains six processes and the right approximately 54 processes due to the decussation of the majority of fibers exiting the NR from the left side (Hedgecock et al., 1990). Near the junction of the NR, anterior to the decussation, the ventral ganglion region contains 170 processes. The VNC is continuous with the RVG at the anterior and with the PAG at the posterior end. Many of the tail neuron processes enter the right tract of the VNC, although a few enter the left tract. In the VNC, motor neuron processes may navigate between different neighborhoods to accommodate input from interneurons within the fascicle as well as their output to muscle arms positioned outside of the cord. This switch in neighborhood generally occurs at the transition between the presynaptic and post-synaptic regions of each motor neuron. The second largest nerve in the nematode, the DC, is a single tract localized on the left side of the dorsal hypodermal ridge and mainly consists of commissural processes from the VNC motor neurons joined by the processes of a small set of neurons in the head (RMED, RID) and tail (PDA, PDB). The processes within a nematode nerve cord are nonmyelinated, and available physiological evidence suggests that they do not conduct action potentials (Davis and Stretton, 1992; Goodman et al., 1998). All nerve bundles run in direct contact with the hypodermis, with which they share a common basal lamina separating them from the pseudocoelom or neighboring muscle tissue. 2.9 Commissures Commissures are circumferential tracts that are created by neuron processes passing from one longitudinal nerve to another through dorsoventral routes. Whereas in higher animals a commissure normally consists of dozens or even thousands of processes, in the nematode a commissure can consist of a single process that pioneers its own route along the body wall. The major commissures include amphid and deirid commissures in the head and lumbar, dorsorectal, and dorsolateral commissures in the tail. There are more than 40 individual commissures along the length of the body where VNC motor neuron processes extend to reach the dorsal side (NeuroFIG 7). The NR, which comprises the largest and most complex region of neuropil in the animal, is essentially an enlarged commissural region encircling the pharyngeal isthmus, with some 200 processes involved, most running a half-circle around the ring. Inside the pharynx, two shorter commissures, the pharyngeal nerve ring and the terminal bulb commissure, connect dorsal and sub-ventral pharyngeal nerve cords (see Alimentary System - Pharynx). Topologically, the commissures follow two types of routes: medial and lateral (NeuroFIG 12) (White et al., 1986; Durbin, 1987). The fibers in the NR follow a medially positioned route between the basal face of the hypodermis and the central muscle arm plate. During development, pioneer axons for the NR are postulated to grow inwardly along extensions of the hypodermis or along the muscle arms of the head muscles, which themselves may be organized by the GLR scaffold cells (See GLR cells). Other commissures following such medial routes include those from the dorsorectal ganglion to the preanal ganglion in the tail (Hall, 1977; Hall and Russell, 1991) and the ventrally directed HSN processes. NeuroFIG 12: Commissures take medial or lateral routes. Fibers traveling circumferentially within the two sides of the NR are examples of medially situated commissures. They are separated from the central muscle plate by the basal lamina of the muscle arms (orange ring). Posterior to the head, body commissures travel circumferentially along a lateral route, sandwiched between the hypodermis and the muscle, and are separated from the muscle by a basal lamina (orange lines). Laterally positioned commissural routes are much more common. In these cases, neuron processes travel singly or in groups along a closely confined space underneath the body wall muscles, always in close apposition to the thin sheet of hypodermis that covers the muscle. Again, the nerves remain separated from the muscle by the basal laminae of the muscle and hypodermis. The right-sided VNC neuron commissures reach the DC by crossing over the dorsal hypodermal ridge. 2.9.1 Commissures in the Head There are four major commissures in the head: right and left amphid commissures and right and left deirid commissures (NeuroFIG 13 and NeuroFIG 14). The amphid commissures on both sides are mainly composed of axons of the amphid neurons that extend from the neuron cell bodies toward the ventral nerve cord, passing between the ventral body wall muscle and a thin sheet of hypodermis (NeuroFIG 15 and NeuroFIG 16). They also contain processes that come from the ventral cord. Processes of two such neurons, SAAV and SABV, join the anterior ventral sublateral cords as they exit the amphid commissures. NeuroFIG 13: Head commissures. Many laterally positioned head neurons send processes to the VNC via four head commissures: two amphid and two deirid. A. Graphic rendition showing only the left-side commissures. Amphid commissures are situated on the left and right sides, immediately anteriorly to the terminal bulb of the pharynx. They are mostly comprised of the axons of the amphid neurons. Deirid commissures allow axons from the neurons situated on the lateral sides of the posterior pharynx to enter the VNC. The majority of the fibers in these commissures travel to the NR. (Ep) Excretory pore. B. Epifluorescent image from an animal expressing the reporter gene str-2::GFP in AWCL. Each AWC axon travels via the amphid commissure (arrowhead), left lateral view. The pharynx is outlined in green. Magnification, 600x. (Strain source: C. Bargmann.) C. Epifluorescent image from an animal expressing the reporter gene dat-1::GFP in ADE neurons, left lateral view. The ADEL axon travels posteriorly to enter the left deirid commissure (arrowhead) and then anteriorly into the ventral ganglion. The pharynx is outlined in green. Magnification, 600x. (Strain source: S. Clark.) NeuroFIG 14: The composition of the left-side amphid commissure. A. Schematic of the commissure, left lateral view. The axons of the amphid neurons enter the VNC through the ipsilateral amphid commissure en route to the NR. (The trajectory of the RIBL axon within the commissure is shown in more detail in NeuroFIG 15.) The ventral process of RID, a single neuron situated in the dorsal ganglion, runs down stochastically on one side of the NR and enters the VNC. It then exits the VNC via the same-side amphid commissure and continues as a commissure to reach the DC. The processes of SABV and SAAV join the anterior subventral cords through the amphid commissures. The posterior part of the amphid commissure, which is also referred to as the sublateral commissure, consists of the processes that are entering or exiting the ventral sublateral cords. (Based on White et al., 1986.) B. TEM of the left amphid commissure, transverse view. Also shown is one of the neurons that sends an axon to the commissure, ASJL. Processes travel between the muscle and hypodermis, underneath the hypodermal basal lamina. The VNC is split into two approximately equal thickness bundles at this level, split by the excretory pore and ventral hypodermal ridge. The processes from the left-sided commissure join the left side of the VNC (dotted red line). Bar, 1 μm. (Image source: [MRC] N2T-101-15.) C. Confocal image from transgenic animals expressing unc-104::GFP reporter gene showing longitudinal and circumferential fiber tracts and commissures in the head, lateral view (See also NeuroFIG 19A). (Image source: O.I. Wagner. Image taken by Wu Gong-Her on an Olympus FV1000 at NSRRC, Hsinchu, Taiwan; strain generated by D.R. Klopfenstein.) NeuroFIG 15-1: Detailed route of an amphid commissure. The trajectory of one of the processes that comprise the left amphid commissure (RIBL interneuron) is shown through sequential TEM images overlayed with color and graphics. After originating from cell bodies situated in lateral ganglia (1), the left- and right-side RIB axons first travel ventrally and slightly posteriorly within the amphid commissures (2) until they reach the junction of the hypodermis and ventral body wall muscle. From here, they make a medial turn (3) and travel on the ventral side of the axon bundle anteriorly and medially until they meet the VNC (4). Once they reach their positions in the ventral cord, they turn anteriorly (5) and travel toward the NR (6). Green color on TEMs indicates the body wall muscles. The TEMs on the right side are the same as those used to generate the sequential and layered image on the left. (Bottom right schematic image) Area of the sections from a right lateral view. (Image source: [MRC] N2T.) NeuroFIG 15-2: Development of the amphid commissure and the nerve ring (NR). A. TEM image (cross section) of a 350 min embryo (after first cell division) showing the nascent commissure fibers traveling between the head muscle and the SIBD neuron that has lodged itself between the muscle and the hypodermis (Hyp). B. Schematic representation of the amphid commissure development. 350 min embryo (after first cell division). At this stage muscle cells (mu) that surround the pharynx primordium may be preventing a more direct, i.e. lateral, route to the NR (indicated with crosses) for the processes of the lateral ganglia neurons that are trying to reach the NR. EC, excretory cell; LG, lateral ganglion; VG, ventral ganglion C. Schematic representation of the NR development. 430 min embryo (after first cell division). Muscle cells have migrated to their final positions next to hypodermis, leaving a trailing process behind that remains attached close to the pharynx. Processes from the remaining lateral ganglia neurons can now reach the NR directly from a lateral route rather than having to travel ventrally first. The pioneering neuron to grow a lateral process into the NR is thought to be AVA. Ventrally, RIH is positioned to navigate processes growing into the NR (C. Norris, D. H. Hall, E. Hedgecock, unpublished observations) (Image source: [Hall archive] N611_402.) NeuroFIG 16: Disposition of neuron tracts in all four head commissures. Left lateral view.The amphid commissures are situated at the anterior of the terminal bulb, and the deirid commissures are situated at the posterior of the terminal bulb of the pharynx. The process of SABD travels dorsally through the right amphid commissure to reach the subdorsal cords. The white line indicates that not the whole bulb but rather only the anterior and posterior regions of the bulb are shown. The positioning of the fibers within the commissures is not invariable. (Based on White et al., 1986.) Amphid commissures are located laterally to the junction of the pharyngeal isthmus and terminal bulb. The posterior sections of the amphid commissures are also referred to as sublateral commissures because they are composed of fibers of ventral sublateral cords. Of these, anteriorly traveling PLN processes dive through the amphid commissure to join the VC on their way to the NR, whereas posteriorly traveling SIBV, SMBV, SIAV, and SMDV processes use amphid commissures to join the ventral sublateral cords. The compositions of the right and left amphid commissures are nearly mirror images of each other. The RID process (on the left side) and the SABD process (on the right side) are the exceptions. The deirid commissures run near the posterior part of the terminal bulb of the pharynx (NeuroFIG 16 and NeuroFIG 17). Originating from their neuronal cell somata on the lateral sides of the head, the processes within the deirid commissures first travel posteroventrally and then medially among the cells of the retrovesicular ganglia until they join the VC. They turn anteriorly in the VC and travel to the NR. AQR is present only on the right side. NeuroFIG 17: The left deirid commissure. A. Neurons situated posteriolaterally to the terminal bulb send their axons to the VNC via the deirid commissures. Processes travel between the hypodermis and muscle and enter the VNC between cell bodies of the RVG neurons. (Orange line) Basal laminae of the hypodermis and muscle; (VBWmu) ventral body wall muscle. B. Epifluorescent image from an animal expressing the reporter gene dat1::GFP in ADE, ventral view. (Arrowheads) Portions of the ADE processes that are within the deirid commissures. Magnification, 600x. (Strain source: S. Clark.) 2.9.2 Commissures in the Tail There are three pairs of commissures in the tail: right and left lumbar commissures (also called ano-lumbar commissures), right and left dorsorectal commissures (also called rectal commissures), and right and left dorsolateral commissures (NeuroFIG 8 and NeuroFIG 18). The lumbar commissures are made of processes of PQR (left side), DA8 (left side), DA9 (right side), PDB (right side), PDA (right side), PVR (right side), PHAL/R, PHBL/R, PHCL/R, PVQL/R, LUAL/R, PVCL/R, PVWL/R, and PVNL/R. The majority of fibers in the lumbar commissures travel ventroanteriorly toward the PAG after originating from the lumbar ganglia neurons. However, the processes of PDA, DA9, DA8, and PDB neurons, which are situated in the PAG, travel posterodorsally through the lumbar commissures. The PDB process then continues traveling toward the tail and makes a dorsal turn within the tail tip to reach the DC, whereas the processes of PDA, DA9, and DA8 motor neurons continue their dorsal trajectory to the DC along the dorsolateral commissures. The dorsorectal commissures contain processes from DVA (right-side), AVFR (right-side), DVB (left-side), DVC (left-side), and AVG (left-side) neurons. The three dorsorectal ganglion neurons (DVA, DVB, DVC) grow their processes ventrally toward the PAG (Hall and Russell, 1991). NeuroFIG 18: Commissures in the tail. Anterior is to the right in all images. A. The two lumbar ganglia are connected to the preanal ganglion (PAG) by lumbar commissures on the ventral side and to the DC by dorsolateral commissures on the dorsal side. The three dorsorectal ganglion neurons grow their processes ventrally toward the PAG via the left- and right-side dorsorectal commissures. B. Right and left lumbar commissures (arrows). Dorsorectal commissures are not visible at this epifluorescent image of a transgenic animal expressing the unc119::GFP panneural reporter, right lateral oblique view. Magnification, 400x. (Strain source: CGC.) C. DA9, a VNC motor neuron situated in the PAG, sends its posteriorly directed process to the DC via lumbar and dorsolateral commissures (arrow). Epifluorescent image from a transgenic animal expressing the itr1pB::GFP reporter gene, right lateral view. Magnification, 600x. (Strain source: H. Baylis and N. Gower.) (Left inset) Graphic rendition of the same neuron. D. DVB is located in the DRG and sends its process to the PAG via a left-sided dorsorectal commissure (arrow). Epifluorescent image from a transgenic animal expressing unc-47delta::GFP, right lateral view. Magnification, 600x. (Strain source: Y. Jin and O. Hobert.) (Right inset) Schematic rendition of the same neuron. E. Organization of tail commissures and the preanal region in newly hatched L1, filleted dorsal view. Processes from PVQ, PHA, PHB, LUA, and PVC neuron pairs assemble into two fascicles that pass between the hypodermis and ventral body wall muscles to reach the VNC. The PVR process travels within the right-side fascicle. The posteriorly directed processes from DA8 and DA9 also run within these fascicles on the left and right sides, respectively. At the preanal region, the anteriorly directed processes meet and reassort with processes from dorsorectal neurons (DVA, DVC), head ganglia interneurons (AVA, AVD, AVG, AVH, AVJ, AVK, AVL), and PAG neurons (PVT, PVP, DD6, DA8, DA9). As they extend anteriorly, they make en passant synapses with their neighbors in the preanal region and the VNC (not shown). PHA and PHB axons and LUA processes end in the preanal region. (SD) Subdorsal; (SV) subventral; (IN) head interneuron processes; (R) rectum. (Based on Hedgecock et al., 1985.) 2.9.3 Commissures in the Body Of the 46 VNC motor neurons that extend processes to the dorsal side, 44 (7 DA, 7 DB, 6 DD, 13 VD, and 11 AS) send their processes via body commissures, whereas DA8 and DA9 send processes to the DC via tail commissures (NeuroFIG 7 and NeuroFIG 18). The commissural processes in the body are sandwiched between muscle and hypodermis as they travel along the lateral body wall. Most of these processes travel on the right side of the animal; however, 11 of them (DA1, DA3–7, DB2, DB4, DB5, DD1, VD2) make left-sided commissures (NeuroFIG 19 and NeuroFIG 20). Many travel alone or at times, two processes can join together to travel in a single commissure. The anteriormost right (made by VD1 and SABD processes) commissure is located near the posterior end of the terminal bulb of the pharynx, whereas the left (made by DB1) is around the procorpus of the pharynx (NeuroFIG 8 and NeuroFIG 20). The posteriormost body commissure (made by AS11) is close to the preanal ganglion in the tail. Along the body, other neuron processes travel dorsally or ventrally to reach longitudinal process tracts and make shorter commissures. These include SDQ dorsal processes extending to the dorsal sublateral tract on each side; HSN, PLM, PDE, and PVD ventral processes to the VNC on each side; AVM ventral process to the VNC on the right side; and PVM ventral process to the VNC on the left side. NeuroFIG 19: Nerve tracts and commissures of the head. A. Longitudinal and circumferential fiber tracts in the head, left lateral view. Six labial process bundles are composed of the dendrites of the cephalic, inner, and outer labial neurons. Two amphid process bundles consist of amphid neuron dendrites and run on the lateral sides of the head. Other neuron processes, including BAG, FLP, URB, GLR, URY, URA, and URX, which have ciliated and non-ciliated endings, also travel within the labial nerve bundles and terminate in the anterior head or lips. The labial neuron axons run posteriorly within the labial nerves, pass along the outside of the ring, and then turn anteriorly and enter the NR to make synapses. Four minor tracts run subdorsally or subventrally and contain processes from SAA and SAB neurons. Anterior to the nerve ring, dorsal and ventral processes from the VNC motor neurons travel anteriorly in close association with dorsal and ventral hypodermal ridges. Posterior to the nerve ring, circumferential tracts follow lateral routes on the right or left sides between the dorsal and ventral levels (see NeuroFIG 13 and NeuroFIG 14). (Modified, with permission of The Royal Society of London, from White et al., 1986.) B. Epifluorescent images from transgenic animals expressing the GABAergic neuron-specific unc-47::GFP reporter gene. The commissures (arrowheads) of the VNC motor neurons mostly travel on the right side of the body as single processes or as thin bundles of a few processes, lateral (top panel) and ventral (bottom panel) views. Anterior is to the left. Note that the left fascicle of the VNC (red dotted line) is not visible in these images, because the neurons that comprise (L) VNC do not express the GFP marker of this strain. The D-type motor neuron cell bodies are visible along the VNC, close to the right fascicle. Magnification, 600x. (Strain source: K. Schuske and E. Jorgensen.) NeuroFIG 20: Body commissures travel circumferentially to reach the dorsal cord. A. Epifluorescent image from a transgenic animal expressing the GABAergic neuron-specific unc-47::GFP reporter gene. The commissure from the VD1 neuron travels dorsally on the right side of the body, whereas the commissure from the DD1 neuron travels on the left, dorsal view. (Strain source: K. Schuske and E. Jorgensen.) B. TEM at the level of the posterior pharyngeal region, transverse section. At this level, the DC straddles the dorsal hypodermal ridge (cf. NeuroFIG 5E). The commissural processes reach the DC by traveling between muscle and hypodermis, underneath the basal lamina. Several muscle arms cluster near the DC, across the basal lamina. (hmc) Head mesodermal cell. Bar, 1 μm. (Image source: [MRC] N2U-A239-20.) 2.10 Synapses The most important concentrations of synapses (also referred to as neuropils) are the NR, VNC, and DC. The tail has an additional region of specialized neuropil in the preanal ganglion that is substantially enlarged in the adult male tail. Very sparse chemical synapses are also found along the sublateral nerve cords, but practically none are found in the other longitudinal nerves, including the amphid, phasmid, or the lateral nerves. Synapses involving commissural axons are apparently rare except for those locations in which a commissure crosses in close proximity to a longitudinal nerve. In general, the ganglia consist entirely of cell bodies and have no synapses. However, the lumbar and dorsorectal ganglia of the male tail also include small regions of neuropil. Occasional chemical synapses may also include alternate cell types as apparent post-synaptic partners, including hypodermal fingers in the nerve cords, marginal (epithelial) cells in the pharynx, the excretory gland, and some sex-specific epithelial cells. 2.10.1 Chemical Synapses In C. elegans, chemical synapses may occur between one presynaptic and one post-synaptic cell (a monad) or more than one post-synaptic partner (a polyad; two recipients make it a dyad and three recipients make it a triad), and one may be muscle (NeuroFIG 21). Chemical synapses are made en passant between neighboring processes where synaptic swellings are formed along the process shafts. These synapses are distinguished by the presence of a small (~50 nm wide and 100–400 nm long), electron-dense presynaptic density on the cytoplasmic side of the membrane. A small cluster of synaptic vesicles lies near this density both docked and in reserve pools that comprise the “active zone” (Weimer and Jorgensen, 2003; Rostaing et al., 2004; Zhen and Jin, 2004; Nakata et al., 2005). Further away from the active zone is a periactive zone, where molecules that coordinate synaptic organization and growth are localized and vesicle membrane may be recovered by endocytosis (Jin, 2002; Rostaing et al., 2004; Nakata et al., 2005). The size of the presynaptic region varies considerably even within the same neuron or among synapses of the same type of neuron (Jin, 2005). NeuroFIG 21: Chemical synapses and NMJs occur en passant in C. elegans. A. Synapses can occur in a monadic (single postsynaptic partner) or polyadic (multiple post-synaptic partners for a single presynaptic neuron) fashion. (Top) Schematic rendition of a monadic and a dyadic synapse. (Bottom) TEM of a dyadic NMJ between the VA4 motor neuron and the DD2 neuron and a ventral body wall muscle arm. (Image source: [MRC] N2U [VC].) B. Schematic rendition of an NMJ. The presynaptic motor neuron and post-synaptic muscle arm are separated by the basal lamina. When there is another motor neuron at the receiving end at (polyadic) NMJs, this post-synaptic neuron is on the same side of the basal lamina as the presynaptic neuron. (SV) Synaptic vesicle. C. TEM shows an NMJ between a VD neuron and several muscle arms, transverse section. Basal-lamina-associated proteins nidogen/entactin (NID-1) (yellow line) and type XVIII (CLE-1) collagen (brown line) are drawn on the original image. Additional presynaptic sites occur on this VD process as it extends to the anterior and posterior of this region. (Left inset) The same synaptic region, magnified. At the point of contact with the post-synaptic elements, the presynaptic process enlarges into a varicosity with a specialized darkly staining bar at the active zone (thick arrow) and contains many SVs (thin arrows) close to MTs (arrowheads). (Right inset) The approximate section level, schematically. Bar, 1 μm. (Image source: [MRC] N2U[VC]-2167-8.) D. TEMs of sublateral cords, transverse sections. (Top panel) Dense core vesicles (DCV), which may contain neuropeptides capable of modulating muscle contractility, clustered in a sublateral cord process. (Image source: N501C [Hall] 3538.) (Bottom panel) Synapse between two sublateral cord processes (arrowhead). Occasionally, sublateral cord processes also make NMJs onto nearby body wall muscles (not shown). (M) Muscle; (Cu) cuticle. (Image source: [MRC] N2U [ring and cords].) E. TEM of the NR, transverse section. Two neurons are seen synapsing onto a third neuron sandwiched between them. Synaptic varicosities (V) contain synaptic vesicles clustered at the active zones featuring presynaptic dense bars (arrows). MTs (arrowhead) are placed near the vesicle clusters and DCVs are seen at the periphery. Bar, 1 μm. (Image source: Hall archive.) Unlike vertebrates, little or no specialization is evident by standard TEM on post-synaptic membranes in C. elegans, and, therefore, proximity determines synaptic partners. Immunochemical staining has recently confirmed that post-synaptic receptors are clustered on the post-synaptic processes, very close to the presynaptic release zone, and improved fixation methods show the presence of small post-synaptic densities (NeuroFIG 21) (Gally et al., 2004; Jin, 2005; J.-L. Bessereau and R. Weimer, pers. comm.). Recent physiological studies of neuromuscular junctions in C. elegans support the observation that a single neuron can elicit responses in multiple post-synaptic elements (Liu et al., 2006). The synaptic cleft generally appears unspecialized in the nematode. As in other organisms, rapid neurotransmission in C. elegans uses classical neurotransmitters, including various monoamines, acetylcholine, GABA, and glutamate. The synaptic vesicles (SV) for classical neurotransmitters that are present at the release zone tend to be small and spherical (30–45 nm in diameter) and have clear contents. The absolute number of nearby vesicles ranges from 10 to 100 in the readily releasable pool. Docked vesicles are closely tethered to the presynaptic membrane within 75 nm of the presynaptic density. Cytoplasmic dense material often surrounds some or all of these vesicles, making the release zone darker than the nearby axoplasm. Vesicles are initially formed in the cell body and may lie in small clusters in the soma cytoplasm before being actively transported down the axon (Hall and Hedgecock, 1991). These transport vesicles are larger in diameter (50 nm) and more electron-dense in contents than the vesicles clustered at the release zone. While traveling along the axon as the cargo of MT-based motors, transport vesicles lie in close proximity to the MT bundle of the nerve process (Hall and Hedgecock, 1991; Zhou et al., 2001). In contrast to SVs, which are clustered near the release sites, large dense-core vesicles (LDCV; 40–50 nm) that contain proneuropeptides and copackaged proprotein-processing enzymes are seen throughout the presynaptic compartment (NeuroFIG 21D) (Jacob and Kaplan, 2003). C. elegans contains more than 150 putative neuropeptides that are thought to modulate synaptic function but can also mediate rapid neurotransmission via gated ion channels (Richmond and Broadie, 2002). A large fraction of C. elegans neurons use peptide neurotransmitters, and a range of behavioral defects are observed in mutants lacking these enzymes. The molecular mechanisms used for transport and membrane fusion of LDCV share some components, such as UNC-104, with those used in rapid synaptic vesicle neurotransmission. Small clusters of free ribosomes have been seen at both presynaptic swellings and in post-synaptic processes (Rolls et al., 2002). These ribosomes may permit local translation of messages in distal neurites. 2.10.2 Neuromuscular Junctions Neuronal input to muscles occurs at specialized chemical synapses called NMJs (NeuroFIG 2D and NeuroFIG 21; also see Muscle system - Introduction). The anatomical features of these synapses are essentially the same as those for chemical synapses between neurons; however, one distinction is the basal lamina that separates the presynaptic motor neuron and the postsynaptic muscle. Basal-lamina-associated proteins nidogen/entactin (NID-1) and type XVIII (CLE-1) collagen are enriched near synaptic contacts. Nidogen is concentrated between the nerve cords and muscles, whereas CLE-1 is concentrated above the regions in which NMJs form (Ackley et al., 2003). Mutations in these basal lamina proteins lead to defects in the organization of NMJs. In contrast to most other organisms, muscles extend long, thin processes (arms) to nerve bundles to make synapses with the motor neurons in C. elegans. In many cases, chemical synapses onto muscle arms occur in specialized zones where several muscles extend arms that interdigitate to form a “muscle plate” around a presynaptic specialization so that vesicle release from a single axon can simultaneously stimulate more than one muscle (White et al., 1976, 1986; Liu et al., 2006). In addition, there are often gap junctions between these muscle arms. For example, along the VNC and DC, muscle arms crowd around the presynaptic varicosities of the motor neurons to receive simultaneous input. Besides the VNC and DC, NMJs are also concentrated on the inside surface of the NR where muscle arms from head muscle rows arrange into a circumferential muscle plate. Unlike somatic muscles, pharyngeal muscles do not form arms, and presynaptic processes are often embedded directly in the muscle soma. In the male tail, presynaptic motor axons often terminate at the synapse, and again, contact is sometimes made directly onto the muscle soma for certain sex muscles. 2.10.3 Electrical Synapses (see also chapter on Gap Junctions) Electrical synapses, or gap junctions (GJs), form by close contact between cells. They are found virtually in all tissues of C. elegans, and essential for embryogenesis (Phelan 2005). In the nervous system, gap junctions are made between neurons and between muscle cells (but not between neurons and muscle cells as they are generally separated by a basal lamina.) The adult C. elegans nervous system has about 600 highly reproducible neuronal gap junctions, in addition to the 5000 predicted chemical synapses (White et al., 1986). The number of gap junctions throughout the life cycle of the animal is likely much higher as some neuronal gap junctions are assembled during embryonic development but are remodeled in early larval stages and dissolved by the adult stage (Chuang et al., 2007). Between neurons, axon-to-axon and axosomatic contacts are common; soma-to-soma contacts are less common. Electrical synapses can occur at any locale within the nervous system; they are not restricted to any neuropil. These synapses may affect behavioral events by synchronizing neuronal activity, by cross-inhibition of neighboring axons, or by relaying signals along neighboring segmental regions from one homolog to another. Alternately, the gap junction may transmit metabolic signals. Some GJs have a developmental role in halting axon outgrowth when two homologous axons establish the limits of their neighboring territories, an event known as contact termination (White et al., 1986). These GJs between homologs are very common; many bilateral neuron pairs in the head encircle only half of the NR (cf. ASH, ASI, ASJ, etc.), because they stop when they encounter the process of their functional homolog to form a GJ. This property is also seen in VD motor neurons along the VNC. Important synaptic connections in the VNC can involve GJs between a command interneuron (AVA or AVB) and the cell body of a motor neuron (White et al., 1976, 1986). Other functions for gap junctions include regulation of asymmetric gene expression in a neuron pair and synchronization of neuron and muscle activities (e.g., synchronization of action potentials and Ca++ transients in body-wall muscle, Ca++ wave propogation during defecation motor program, facilitation of intermuscular electrical coupling for synchronous pharyngeal muscle contractions, transmission of signals among male-specific muscles during male copulation) (Liu et al, 2011a; Liu et al., 2011b; Chuang et al., 2007; Peters et al., 2007, Li et al, 2003). During embryogenesis transient gap junction networks may regulate formation of nascent circuits (Chuang et al., 2007). NeuroFIG 22: Gap junctions in C. elegans. A. Graphic rendition of subunit composition of homotypic, heterotypic, and heteromeric gap junctions. B. Fluorescent micrograph of a transgenic animal expressing the Punc-9::GFP reporter gene in neural and muscle tissues. Bwmu, body wall muscles; um, uterine muscles; vm, vulval muscles; VNC mn, ventral nerve cord motor neurons. Arrow indicates position of vulva. Scale bar: 10 μm. Ventral view. GJs in nematodes are formed by intramembrane proteins called “innexins,” which are completely different in their amino acid sequence from the vertebrate “connexins.” Instead, they are the homologs of vertebrate "pannexins" (Starich et al., 1996; Phelan and Starich, 2001; Altun et al., 2009). They may coassemble to form homotypic, heterotypic and heteromeric gap junctions (NeuroFIG 22). Additionally, these molecules may form hemichannels that connect a cell’s interior to the extracellular space, providing a pathway for release and uptake of molecules and ions in a controlled manner. In addition to eat-5, unc-7, and unc-9, which had been discovered previously through mutant analyses, the completion of genomic sequencing of C. elegans revealed 22 more innexin genes (C. elegans Sequencing Consortium, 1998; Bargmann, 1998). These additional innexins were numbered arbitrarily from inx-1to inx-22. Further sequencing and genomic analysis of two additional Caenorhabditis species (C. briggsae and C. remanei) revealed that each of these species has retained at least one member of each type of these innexins, except inx-8 and inx-9, which share a single ortholog in C. briggsae, but have distinct orthologs in C. remanei (see Wormbase). This strongly suggests that each innexin gene is a true gene rather than a pseudogene. Among C. elegans innexins, there are 3 sets of polycistronic ones: inx-12 and inx-13, inx-16 and inx-17, and inx-21, and inx-22. Individual GJs in neurons can involve heteromeric channels made from several different innexin subunits. Neuronal GJs differ from those in other nematode tissues by showing equal numbers of intramembrane particles in both the “E-face” and “P-face” (Hall, 1987). Through expression analyses all innexins except inx-5, inx-15, inx-16, inx-20, inx-21, inx-22, and eat-5 were found in the C. elegans nervous system (Altun et al., 2009). Among these, the most widely expressed innexins were inx-7, unc-7, and unc-9, while the least widely expressed ones were inx-1, inx-2, and inx-11. Also, TEM analyses revListealed that gap junctions exist between glia (socket and sheath cells) and hypodermis as well as between the socket and sheath cells, but not between glia and neurons (Altun et al., 2009). 3 List of Neurons Individual neurons Use drop down menus to go to individual neuron pages. 4 References Ackley, B.D., Kang, S.H., Crew, J.R., Suh, C., Jin, Y. and Kramer, J.M. 2003. The basement membrane components nidogen and type XVIII collagen regulate organization of neuromuscular junctions. J. Neurosci. 23: 3577-3587. Article Albeg, A., Smith, C.J., Chatzigeorgiou, M., Feitelson, D.G., Hall, D.H., Schafer, W.R., Miller, D.M. and Treinin, M. 2011. C. elegans multidendritic sensory neurons: morphology and function. Mol. Cell. Neurosci. 46: 308-317. Article Albertson, D.G. and Thomson, J.N. 1984. The pharynx of C. elegans. Phil. Trans. Royal Soc. London 275B: 299-325. Article Alcedo, J. and Kenyon, C. 2004. Regulation of C. elegans longevity by specific gustatory and olfactory neurons. Neuron 41: 45–55. Article Altun-Gultekin, Z.F., Andachi Y., Tsalik, E.L., Pilgrim, D., Kohara, Y. and Hobert, O. 2001. A regulatory cascade of three homeobox genes, ceh-10, ttx-3 and ceh-23, controls cell fate specification of a defined interneuron class in C. elegans. Development 128: 1951-1969. Article Altun, Z.F., Chen, B., Wang, Z-W. and Hall, D. H.. 2009. High resolution map of Caenorhabditis elegans gap junction proteins. Dev. Dyn. 238: 1936-1950. Article Antebi, A., Norris, C.R., Hedgecock E.M. and Garriga G. 1997. Cell and growth cone migrations. In C. elegans II (ed. D.L. Riddle et al.), pp. 583–609. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Appelby, P. A. 2012. A model of chemotaxis and associative learning in C. elegans.Biological Cybernetics. 106: 373-387. Article Aprison, E.Z and Ruvinsky, I. 2014. Balanced trade-offs between alternative strategies shape the response of C. elegans reproduction to chronic heat stress. PLoS ONE 9: e105513. Article Arnadottir, J., and Chalfie, M. 2010. Eukaryotic mechanosensitive channels. Ann. Rev. Biophysics. 39: 111-137. Article Aurelio, O., Hall, D.H. and Hobert, O. 2002. Immunoglobulin-domain proteins required for maintenance of ventral nerve cord organization. Science. 295: 689-690. Abstract Avery, L. and Thomas, J.H. 1997. Feeding and defecation. In C. elegans II (ed D.L. Riddle et al.), pp. 678–716. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Bargmann, C.I., and Avery, L. 1995. Laser killing of cells in Caenorhabditis elegans: Modern biological analysis of an organism (ed. Epstein, H.F. and Shakes, D.C.). Chapter 10. pp 225-249. Academic Press, California. Abstract Bargmann, C.I. 1998. Neurobiology of the Caenorhabditis elegans Genome. Science 282: 2028-2033. Article Bargmann, C.I. 2006. Chemosensation in C. elegans. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.123.1. Article Bargmann, C.I and Horvitz, H.R. 1991. Control of larval development by chemosensory neurons in Caenorhabditis elegans. Science 251: 1243-1246. Abstract Bargmann, C.I., Hartwieg, E. and Horvitz, H.R. 1993. Odorant-selective genes and neurons mediate olfaction in C. elegans. Cell 74: 515– 27. Abstract Bargmann, C.I. and Mori, I. 1997. Chemotaxis and thermotaxis. In C. elegans II (ed. D.L. Riddle et al.), pp. 717–737. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Barr, M.M. and Garcia, L.R. 2006. Male mating behavior. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.7.1. Article Bergamasco, C. and Bazzicalupo, P. 2006. Chemical sensitivity in C. elegans. Cell Mol. Life Sci. 63: 1510-1522. Abstract Bird, A.F. and Bird. J. 1991. The structure of nematodes. Academic Press, California. Bounoutas, A. and Chalfie, M. 2007. Touch sensitivity in Caenorhabditis elegans. European J. Physiol. 454: 691-702. Article Bretscher, J., Busch, K.E. and de Bono, M. 2008. A carbon dioxide avoidance behavior is integrated with responses to ambient oxygen and food in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 105: 8044-8049. Article Bretscher, J.A., Kodama-Namba, E., Busch, K.E., Murphy, R.J., Soltesz, Z., Laurent, P. and de Bono, M. 2011. Temperature, oxygen, and salt-sensing neurons in C. elegans are carbon dioxide sensors that control avoidance behavior. Neuron 69: 1099-1113. Article Bülow, H.E. and Hobert, O. 2006. The molecular diversity of glycosaminoglycans shapes animal development. Annu Rev. Cell Dev. Biol. 22: 375-407. Abstract Bülow, H.E., Berry, K.L., Topper, L.H., Peles, E. and Hobert O. 2002. Heparan sulfate proteoglycan-dependent induction of axon branching and axon misrouting by the Kallmann syndrome gene kal-1. Proc. Natl. Acad. Sci. 99: 6346-6351. Article Burr, A.H.J. 1985. The photomovement of C. elegans , a nematode which lacks ocelli. Proof that the response is to light not radiant heating. Photochem. Photobiol. 41: 577-582. Abstract Chalfie, M. 1993. Touch receptor development and function in Caenorhabditis elegans. J. Neurobiol. 24: 1433-1441. Abstract Chalfie, M. and Sulston, J.E. 1981. Developmental genetics of the mechanosensory neurons of C. elegans. Dev. Biol. 82: 358-370. Abstract Chalfie, M. and Thomson, J.N. 1979. Organization of neuronal microtubules in the nematode Caenorhabditis elegans. J. Cell Biol. 82: 278-289. Article Chalfie, M. and Thomson, J.N. 1982. Structural and functional diversity in the neuronal microtubules of Caenorhabditis elegans. J. Cell Biol. 93: 15-23. Article Chalfie M. and White J. 1988. The nervous system. In The nematode C. elegans (ed. W.B. Wood), pp. 337–391. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Abstract Chalfie, M., Sulston, J.E., White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1985. The neural circuit for touch sensitivity in Caenorhabditis elegans. J. Neurosci. 5: 956-964. Article Chang, A.J., Chronis, N., Karow, D.S., Marletta, M.A. and Bargmann, C.I. 2006. A distributed chemosensory circuit for oxygen preference in C. elegans. PLoS Biol 4: e274. Article Chatzigeorgiou, M. and Schafer, W.R.. 2011. Lateral facilitation between primary mechanosensory neurons controls nose touch perception in C. elegans. Neuron 70: 299-309. Article Chatzigeorgiou, M. Yoo, S., Watson, J.D., Lee, W.H., Spencer, W.C., et al. 2010. Specific roles for DEG/ENaC and TRP channels in touch and thermosensation in C. elegansnociceptors. Nat. Neurosci.13: 861-868. Article Chen, B.L., Hall, D.H. and Chklovskii, D.B. 2006. Wiring optimization can relate neuronal structure and function. Proc. Natl. Acad. Sci. 103: 4723-4728. Article Cheung, B.H.H., Arellano-Carbajal, F., Rybicki, I. and De Bono, M. 2004. Soluble guanylate cyclases act in neurons exposed to the body fluid to promote C. elegans aggregation behavior. Curr. Biol. 14: 1105-1111. Article Cheung, B.H.H., Cohen, M., Rogers, C., Albayram, O. and De bono, M. 2005. Experience-dependent modulation of C. elegans behavior by ambient oxygen. Curr. Biol. 15: 905–917. Article Chiba, C.M. and Rankin C.H. 1990. A developmental analysis of spontaneous and reflexive reversals in the nematode Caenorhabditis elegans. J. Neurobiol. 21: 543-554. Article Chisholm, A.D. and Jin, Y. 2005. Neuronal differentiation in C. elegans. Curr. Op. Cell Biol. 17: 682-689. Abstract Chitwood, B.G. and Chitwood, M.B. 1950. The nervous system. In An introduction to nematology, pp. 160–174. University Park Press, Baltimore. Chuang, C-F., VanHoven, M. K., Fetter, R. D., Verselis, V. K. and Bargmann, C. I. 2007. An innexin-dependent network establishes left-right neuronal asymmetry in C. elegans. Cell. 129: 787-799. Article Culotti, J.G. and Russell, R.L. 1978. Osmotic avoidance defective mutants of the nematode Caenorhabditis elegans. Genetics 90: 243-256. Article Croll, N.A. 1975. Components and patterns in the behavior of the nematode Caenorhabditis elegans. J. Zoology 176: 159–176. Abstract Davis, R.E. and Stretton, A.O.W. 1992. Extracellular recordings from the motor nervous system of the nematode, Ascaris suum. J. Comp. Physiol. 171: 17-28. Abstract De Bono, M. 2003. Molecular approaches to aggregation behavior and social attachment. J. Neurobiol. 54: 78-92. Article De Bono, M. and Maricq, A.V. 2005. Neuronal substrates of complex behaviors in C. elegans. Ann. Rev. Neurosci. 28: 451-501. Article Driscoll, M. and Kaplan, J. 1997. Mechanotransduction. In C. elegans II (ed. D.L. Riddle et al.), pp. 645–677. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Durbin, R.M. 1987. “Studies on the development and organisation of the nervous system of C. elegans.” Ph.D. thesis. University of Cambridge, United Kingdom. Article Emmons, S.W. 2005. Male development. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.33.1. Article Emmons, S.W. and Lipton, J. 2003. Genetic basis of male sexual behavior. J. Neurobiol. 54: 93-110. Article Faumont, S., Miller, A.C. and Lockery, S.R. 2005. Chemosensory behavior of semi-restrained Caenorhabditis elegans. J. Neurobiol. 65: 171–178. Abstract Fukushige, T., Siddiqui, Z.K., Chou, M. and Culotti, J.G. 1999. MEC-12, an alpha-tubulin required for touch sensitivity in C. elegans. J. Cell Sci. 112: 395-403. Article Gally, C., Eimer, S., Richmond, J.E. and Bessereau, J.L. 2004. A transmembrane protein required for acetylcholine receptor clustering in Caenorhabditis elegans. Nature 431: 578-582. Abstract García-Añoveros, J., García, J. A., Liu, J-D. and Corey, D. P. 2000. The nematode degenerin UNC-105 forms ion channels that are activated by degeneration- or hypercontraction-causing mutations. Neuron. 20: 1231-1241. Article Giles, A.C., Rose, J.K. and Rankin, C.H. 2006. Investigations of learning and memory in Caenorhabditis elegans. Int. Rev. Neurobiol. 69: 37-71. Abstract Goodman, M.B. 2006. Mechanosensation. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.62.1. Article Goodman, M.B. and Schwarz, E.M. 2003. Transducing touch in Caenorhabditis elegans. Annu. Rev. Physiol. 65: 429–452. Abstract Goodman, M.B., Hall, D.H., Avery, L. and Lockery, S.R. 1998. Active currents regulate sensitivity and dynamic range in C. elegans neurons. Neuron 20: 763-772. Article Gray, J.M., Hill, J.J. and Bargmann, C.I. 2005. A circuit for navigation in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 102: 3184-3191. Article Gray J.M., Karow, D.S., Lu, H., Chang, A.J., Chang, J.S., Ellis, R.E., Marletta, M A. and Bargmann, C I. 2004. Oxygen sensation and social feeding mediated by a C. elegans guanylate cyclase homologue. Nature 430: 317-322. Abstract Gu, G., Caldwell, G.A. and Chalfie, M. 1996. Genetic interactions affecting touch sensitivity in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 93: 6577–6582. Article Halevi, S., McKay, J., Palfreyman M., Yassin, L., Eshel, M., Jorgensen, E. and Treinin, M. 2002. The C.elegans ric-3 gene is required for maturation of nicotinic acetylcholine receptors. 21: 1012–1020. Article Hall D.H. 1977. “The posterior nervous system of the nematode Caenorhabditis elegans.” Ph.D. thesis. California Institute of Technology, Pasadena. Hall D.H. 1987. Freeze-fracture and freeze-etch studies of the nematode Caenorhabditis elegans. Ann. N.Y. Acad. Sci. 494: 215–217. Abstract Hall, D.H. and Hedgecock, E.M. 1991. Kinesin-related gene unc-104 is required for axonal transport of synaptic vesicles in C. elegans. Cell 65: 837-847. Abstract Hall, D.H. and Russell, G.J. 1991. The posterior nervous system of the nematode Caenorhabditis elegans: Serial reconstruction of identified neurons and complete pattern of synaptic interactions. J. Neurosci. 11: 1-22. Article Hall, D.H., Lints, R. and Altun, Z. 2006. Nematode neurons: anatomy and anatomical methods in Caenorhabditis elegans. Int. Rev. Neurobiol. 69: 1-35. Abstract Hallem, E.A. and Sternberg, P.W. 2008. Acute carbon dioxide avoidance in Caenorhabditis elegans. Proc. Natl. Acad. Sci.105: 8038-8043. Article Hardaker, L.A., Singer, E., Kerr, R., Zhou, G. and Schafer, W.R. 2001. Serotonin modulates locomotory behavior and coordinates egg-laying and movement in Caenorhabditis elegans. J. Neurobiol. 49: 303-313. Abstract Hart, A.C., Sims, S. and Kaplan, J.M. 1995. Synaptic code for sensory modalities revealed by C. elegans GLR-1 glutamate receptor. Nature 378: 82-85. Abstract Hart, A.C., Kass, J., Shapiro, J.E. and Kaplan, J.M. 1999. Distinct signaling pathways mediate touch and osmosensory responses in a polymodal sensory neuron. J. Neurosci. 19: 1952-1958. Article Hedgecock, E.M. and Russell, R.L. 1975. Normal and mutant thermotaxis in the nematode Caenorhabditis elegans. Proc. Natl. Acad. Sci. 72: 4061–4065. Article Hedgecock, E.M., Culotti, J.G. and Hall, D.H. 1990. The unc-5, unc-6, and unc-40 genes guide circumferential migrations of pioneer axons and mesodermal cells on the epidermis in C. elegans. Neuron 4: 61-85. Abstract Hedgecock, E.M., Culotti, J.G., Thomson, J.N. and Perkins, L. A. 1985. Axonal guidance mutants of Caenorhabditis elegans identified by filling sensory neurons with fluorescein dyes. Dev. Biol. 111: 158-170. Abstract Hedgecock, E.M., Culotti, J.G., Hall, D.H. and Stern, B. D. 1987. Genetics of cell and axon migrations in Caenorhabditis elegans. Development. 100: 365-382. Article Herman, R.K. 2005. Touch sensation in Caenorhabditis elegans. Bioessays 18: 199-206. Abstract Hilliard, M., Bargmann, C.I. and Bazzicalupo, P. 2002. C. elegans responds to chemical repellents by integrating sensory inputs from the head and the tail. Curr. Biol. 12: 730-734. Article Hobert, O. and Bülow, H. 2003. Development and maintenance of neuronal architecture at the ventral midline of C. elegans. Curr. Op. Neurobiol. 13: 70-78. Abstract Hutter, H. 2003. Extracellular cues and pioneers act together to guide axons in the ventral cord of C. elegans. Development 130: 5307-5318. Article Hutter, H., Wacker, I., Schmid, C. and Hedgecock, E.M. 2005. Novel genes controlling ventral cord asymmetry and navigation of pioneer axons in C. elegans. Dev. Biol. 284: 260-272. Article Heiman, M. G. and Shaham, S. 2009. DEX-1 and DYF-7 establish sensory dendrite length by anchoring dendritic tips during cell migration. Cell. 137: 344-355. Article Iino, Y., and Yoshida, K. 2009. Parallel use of two behavioral mechanisms for chemotaxis in Caenorhabditis elegans. J Neurosci. 29:5370-5380. Article Inada, H., Ito, H., Satterlee, J., Sengupta, P., Matsumoto, K. and Mori, I. 2006. Identification of guanylyl cylases that function in thermosensory neurons of Caenorhabditis elegans. Genetics. 172: 2239-2252. Article Jacob, T.C. and Kaplan, J.M. 2003. The EGL-21 Carboxypeptidase E Facilitates Acetylcholine Release at Caenorhabditis elegans Neuromuscular Junctions. J. Neurosci. 23: 2122. Article Jeong P.Y., Jung M., Yim, Y.H., Kim, H., Park, M., Hong, E., Lee, W., Kim, Y.H., Kim, K. and Paik, Y.K. 2005. Chemical structure and biological activity of the Caenorhabditis elegans dauer-inducing pheromone. Nature 433: 541-545. Abstract Jin, Y. 2002. Synaptogenesis; insights from worm and fly. Curr. Opin. Neurobiol.12: 71-79. Abstract Jin, Y. 2005. Synaptogenesis. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.44.1. Article Jorgensen E.M. 2006. GABA. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.14.1. Article Jorgensen, E.M. and Nonet, M.L. 1995. Neuromuscular junctions in the nematode C. elegans. Semin. Dev. Biol. 6: 207-220. Abstract Jospin, M., Mariol, M.C., Segalat, L. and Allard, B. 2004. Patch clamp study of the UNC-105 degenerin and its interaction with the LET-2 collagen in Caenorhabditis elegans muscle. J. Physiol. 557: 379-388. Article Kahn-Kirby, A.H. and Bargmann, C.I. 2006. Trp channels in C. elegans. Annu. Rev. Physiol. 68: 719-736. Abstract Kaplan, J. M. and Horvitz, H. R. 1993. A dual mechanosensory and chemosensory neuron in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 90:2227-2231. Article Knobel, K.M., Davis, W.S., Jorgensen, E.M. and Bastiani, M.J. 2001. UNC-119 suppresses axon branching in C. elegans. Development 128: 4079-4092. Article Kuhara, A., Inanda, H., Katsura, I. and Mori, I. 2002. Negative regulation and gain control of sensory neurons by the C. elegans calcineurin TAX-6. Neuron 33: 751-763. Article Kuhara, A., Okumura, M., Kimata, T., Tanizawa, Y., Takano, R., Kimura, K. D., Inada, H., Matsumoto, K. and Mori, I. 2008 Temperature sensing by an olfactory neuron in a circuit controlling behavior of C. elegans. Science 320: 803-807. Article Li, S., Dent, J. A., and Roy, R. 2003. Regulation of intermuscular electrical coupling by the Caenorhabditis elegans innexin inx-6. Mol. Biol. Cell 14:2630-2644. Abstract Li, W., Feng, Z., Sternberg, P.W. and Shawn Xu, X.Z. 2006. A C. elegans stretch receptor neuron revealed by a mechanosensitive TRP channel homologue. Nature 440: 684-687. Abstract Lipton, J. and Emmons, S.W. 2003. Genetic basis of male sexual behavior. J. Neurobiol. 54: 93-110. Article Lithgow, G., White, T., Melov, S. and Johnson, T. 1995.Thermotolerance and extended life-span conferred by single-gene mutations and induced by thermal stress. Proc. Nat. Acad. Sci. 92: 7540-7544. Abstract Liu, J., Schrank, B. and Waterston, R.H. 1996. Interaction between a putative mechanosensory membrane channel and a collagen. Science 273: 323-324. Abstract Liu, K.S. and Sternberg, P.W. 1995. Sensory regulation of male mating behavior in Caenorhabditis elegans. Neuron 14: 79–89. Article Liu, P., Chen, B. and Wang, Z-W. 2011a. Gap junctions synchronize action potentials and Ca2+ transients in Caenorhabditis elegans body wall muscle. PLoS Genet 7: e1001326.. Article Liu, Y., LeBeouf, B., Guo, X., Correa, P. A., Gualberto, D., Lints, R. and Garcia, R. L. 2011b. A cholinergic-regulated circuit coordinates the maintenance and bi-stable states of a sensory-motor behavior during Caenorhabditis elegans male copulation. J. Biol. Chem .286: 44285-44293. Article Liu, Q. Chen, B., Hall, D.H. and Wang, Z-W. 2006. A quantum of neurotransmitter causes minis in multiple postsynaptic cells at the Caenorhabditis elegans neuromuscular junction. J. Neurobiol. 67: 123-128. Abstract Liu, S., Schulze, E. and Baumeister, R. 2012. Temperature- and touch-sensitive neurons couple CNG and TRPV channel activities to control heat avoidance in Caenorhabditis elegans. PLoS ONE 7: e32360doi:10.1371/journal.pone.0032360. Article McIntire, S.L., Jorgensen, E., Kaplan, J. and Horvitz, H.R. 1993. The GABAergic nervous system of Caenorhabditis elegans. Nature 364: 337-341. Abstract Melkman, T. and Sengupta, P. 2004. The worm’s sense of smell. Development of functional diversity in the chemosensory system of Caenorhabditis elegans. Dev. Biol. 265: 302-319. Article Mellem, J.E., Brockie, P.J., Zheng, Y., Madsen, D.M., Maricq, A.V. 2002. Decoding of polymodal sensory stimuli by postsynaptic glutamate receptors in C. elegans. Neuron 36: 933-944. Article Montell, D.J. 1999. The genetics of cell migration in Drosophila melanogaster and Caenorhabditis elegans development. Development 126: 3035-3046. Article Mori, I. and Ohshima, Y. 1995. Neural regulation of thermotaxis in Caenorhabditis elegans. Nature 376: 344–348. Abstract Mori, I. 1999. Genetics of chemotaxis and thermostaxis in the nematode Caenorhabditis elegans. Annu. Rev. Genet. 33: 399-422. Abstract Nakata, K., Abrams, B., Grill, B., Goncharov, A., Huang, X., Chisholm, A.D. and Jin, Y. 2005. Regulation of a DLK-1 and p38 MAP kinase pathway by the ubiquitin ligase RPM-1 is required for presynaptic development. Cell 120: 407-420. Article O’Hagan, R. and Chalfie, M. 2006. Mechanosensation in Caenorhabditis elegans. Int. Rev. Neurobiol. 69: 169-203. Abstract Ohnishi, A., Kuhara, A., Nakamura, F., Okochi, Y. and Mori, I. 201.1 Bidirectional reulation of thermotaxis by glutamate transmission in Caenorhabditis elegans. Embo J. 30: 1376-1388. Article Perkins, L.A., Hedgecock, E.M., Thomson, J.N., Culotti, J.G. 1986. Mutant sensory cilia in the nematode C. elegans. Dev. Biol. 117: 456-487. Article Peters, M. A., Teramoto, T., White, J. Q., Iwasaki, K.,and Jorgensen, E. M. 2007. A calcium wave mediated by gap junctions coordinates a rhythmic behavior in C. elegans. Curr. Biol. 17: 1601-1608. Article Phelan, P. and Starich, T.A. 2001. Innexins get into the gap. Bioessays 23: 388-396. Abstract Phelan, P. 2005. Innexins: members of an evolutionarily conserved family of gap-junction proteins. Biochim. Biophys. Acta 1711:225-245. Article Pierce-Shimomura, J.T., Morse, T.M. and Lockery, S. 1999. The fundamental role of pirouettes in Caenorhabditis elegans chemotaxis. J. Neurosci. 19: 9557-9569. Article Pierce-Shimomura, J.T., Faumont, S., Gaston, M.R., Pearson, B.J. and Lockery, S.R. 2001. The homeobox gene lim-6 is required for distinct chemosensory representations in C. elegans. Nature 410: 694–698. Abstract Ren, X-C., Kim, S.K., Fox, E., Hedgecock, E.M. and Wadsworth, W.G. 1999. Role of netrin UNC-6 in patterning the longitudinal nerves of Caenorhabditis elegans. J. Neurobiol. 39:107-118. Abstract Richmond, J.E. and Broadie, K.S. 2002. The synaptic vesicle cycle: exocytosis and endocytosis in Drosophila and C. elegans. Curr. Op. Neurobiol. 12: 499-507. Abstract Riddle, D.L. and Golden, J.W. 1982. A pheromone influences larval development in the nematode C. elegans. Science 218: 578-580. Abstract Rittenburg, N. and Baumeister, R. 1999. Thermal avoidance in Caenorhabditis elegans: an approach to the study of nociception. Proc. Nat. Acad. Sci. 96: 10477-10482. Article Rogers, C., Persson, A., Cheung B. and de Bono, M. 2006. Behavioral Motifs and Neural Pathways Coordinating O2 Responses and Aggregation in C. elegans. Curr. Biol. 16: 649-659. Article Rolls, M.M., Hall, D.H., Victor, M., Rapoport, T.A. and Stelzer, E.H. 2002. Targeting of rough endoplasmic reticulum membrane proteins and ribosomes in invertebrate neurons. Mol. Biol. Cell 13: 1778-1791. Article Rostaing, P., Weimer R.M., Jorgensen, E.M., Triller, A. and Bessereau, J-L. 2004. Preservation of immunoreactivity and fine structure of adult C. elegans tissues using high-pressure freezing. J. Histochem. Cytochem. 52: 1-12. Article Ryu WS, Samuel AD. 2002. Thermotaxis in Caenorhabditis elegans analyzed by measuring responses to defined thermal stimuli. J. Neurosci. 22:5727–33. Article Salser, S.J. and Kenyon, C. 1992. Activation of a C. elegans Antennapedia homologue in migrating cells controls their direction of migration. Nature 355: 255-258. Abstract Sambongi, Y., Nagae, T., Liu, Y., Yoshimizu, T., Takeda, K., Wada, Y. and Futai, M. 1999. Sensing of cadmium and copper ions by externally exposed ADL, ASE, and ASH neurons elicits avoidance response in Caenorhabditis elegans. Neuroreport 10: 753–757. Abstract Sasakura, H., Inada, H., Kuhara, A., Fusaoka, E., Takemoto, D., Takeuchi, K. and Mori, I. 2005. Maintenance of neuronal positions in organized ganglia by SAX-7, a Caenorhabditis elegans homologue of L1. EMBO J. 24: 1477-1488. Article Sawin, E.R., Ranganathan, R. and Horvitz, H.R. 2000. C. elegans locomotory rate is modulated by the environment through a dopaminergic pathway and by experience through a serotonergic pathway. Neuron 26: 619-631. Article Schafer, W.R. 2005. Egg-laying. In WormBook (ed. The C. elegans Research Community), WormBook, doi/10.1895/wormbook.1.38.1. Article Sharabi, K, Hurwitz, A., Simon, A.J.,Beitel, G.J., Morimoto, R.I., Rechavi, G., Sznajder, J.I. and Gruenbaum, Y. 2009. Elevated CO2 levels affect development, motility, and fertility and extend life span in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 106: 4024-4029. Article Starich, T.A., Lee, R.Y.N., Panzarella, C., Avery, L. and Shaw, J.E. 1996. eat-5 and unc-7 represent a multigene family in Caenorhabditis elegans involved in cell-cell coupling. J. Cell Biol. 134: 537-548. Article Sulston, J.E. 1976. Post-embryonic development in the ventral cord of C. elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 275: 287-298. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Albertson, D.G. and Thomson, J.N. 1980. The Caenorhabditis elegans male: postembryonic development of nongonadal structures. Dev Biol. 78: 542-576. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Syntichaki, P. and Tavernarakis, N. 2004. Genetic models of mechanotransduction: the nematode Caenorhabditis elegans. Physiol. Rev. 84: 1097-1153. Article Tavernarakis, N., Shreffler, W., Wang, S.L. and Driscoll M.A. 1997. unc-8, a DEG/ENaC family member, encodes a subunit of a candidate mechanically gated channel that modulates C. elegans locomotion. Neuron 18: 107-119. Article Tobin, D.M. and Bargmann, C.I. 2004. Invertebrate nociception: behaviors, neurons and molecules. J. Neurobiol. 61: 161-174. Article Troemel, E.R., Kimmel, B.E., Bargmann, C.I. 1997. Reprogramming chemotaxis responses: sensory neurons define olfactory preferences in C. elegans. Cell 91: 161–169. Article Tsalik, E.L., Niacaris, T., Wenick, A.S., Pau, K., Avery, L. and Hobert, O. 2003. LIM homeobox gene-dependent expression of biogenic amine receptors in restricted regions of the C. elegans nervous system. Dev. Biol. 263: 81–102. Article Van Voorhies, W.A. and Ward, S. 2000. Broad oxygen tolerance in the nematode Caenorhabditis elegans. J. Exp. Biol. 203: 2467-2478. Article Von Stetina, S.E., Treinin, M., and Miller III, D.M. 2006. The motor circuit. Int. Rev. Neurobiol. 69: 125-167. Abstract Wadsworth, W.G. and Hedgecock, E.M. 1996. Hierarchical guidance cues in the developing nervous system of C. elegans. Bioessays 18: 355-362. Abstract Wadsworth, W.G., Bhatt, H. and Hedgecock, E.M. 1996. Neuroglia and pioneer neurons express UNC-6 to provide global and local netrin cues for guiding migrations in C. elegans. Neuron 16: 35-46. Article Walthall, W.W. and Chalfie, M.1988. Cell-cell interactions in the guidance of late-developing neurons in C. elegans. Science. 239: 643-645. Abstract Walthall, W.W., Li, L., Plunkett, J.A. and Hsu, C.Y. 1993. Changing synaptic specifications in the nervous system of Caenorhabditis elegans - Differentiation of the DD motoneurons. J. Neurobiol. 24: 1589-1599. Abstract Ward, S., Thomson, J., White, J. and Brenner, S. 1975. Electron microscopical reconstruction of the anterior sensory anatomy of the nematode C. elegans. J. Comp. Neurol. 160: 313-337. Article Ware, R.W., Crossland, K., Russell, R.L. and Clark, D.V. 1975. The nerve ring of the nematode C. elegans: Sensory input and motor output. J. Comp. Neurol. 162: 71-110. Article Way, J.C. and Chalfie, M. 1989. The mec-3 gene of Caenorhabditis elegans requires its own product for maintained expression and is expressed in three neuronal cell types. Genes Develop. 3: 1823-1833. Article Weimer, R.M. and Jorgensen, E. M. 2003. Controversies in synaptic vesicle exocytosis. J. Cell Science 116: 3661-3666. Article Wes, P.D. and Bargmann, C.I. 2001. C. elegans odour discrimination requires asymmetric diversity in olfactory neurons. Nature 410: 698-701. Abstract White, J.G., Albertson, D.G. and Anness M.A.R. 1978. Connectivity changes in a class of motoneurone during the development of a nematode. Nature 271: 764-766. Abstract White J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1976. The structure of the ventral nerve cord of Caenorhabditis elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 275B: 327-348. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1983. Factors that determine connectivity in the nervous system of C. elegans. Cold Spring Harbor Symp. Quant. Biol. 48: 633-640. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode C. elegans. Philos. Trans. R. Soc. Lond. Series B. Biol. Sci. 314: 1-340. Article Wicks, S.R., Roehrig, C.J. and Rankin, C.H. 1996. A dynamic network simulation of the nematode tap withdrawal circuit: Predictions concerning synaptic function using behavioral criteria. J. Neurosci. 16: 4017-4031. Article Yang, Y. and Lundquist, E.A. 2005. The actin-binding protein UNC115/abLIM controls formation of lamellipodia and filopodia and neuronal morphogenesis in Caenorhabditis elegans. Mol. Cell. Biol. 25: 5158-5170. Article Zhang, Y., Lu, H. and Bargmann, C.I. 2005. Pathogenic bacteria induce aversive olfactory learning in Caenorhabditis elegans. Nature 438: 179-184. Abstract Zhen, M. and Jin, Y. 2004. Presynaptic terminal differentiation: transport and assembly. Curr. Op. Neurobiol. 14: 280-287. Abstract Zheng, Y., Brockie, P.J., Mellem, J.E., Madsen, D.M. and Maricq, A.V. 1999. Neuronal control of locomotion in C. elegans is modified by a dominant mutation in the GLR-1 ionotropic glutamate receptor. Neuron 24: 347–361. Article Zhou, H.M., Brust-Mascher, I. and Scholey, J.M. 2001. Direct visualization of the movement of the monomeric axonal transport motor UNC-104 along neuronal processes in living Caenorhabditis elegans. J. Neurosci. 21: 3749-3755. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2011. Nervous system, general description. In WormAtlas. doi:10.3908/wormatlas.1.18 Edited for the web by Laura A. Herndon. Last revision: June 19, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |